# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_table.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v5.protos.annotations import validation_pb2 as protos_dot_annotations_dot_validation__pb2
from ydb._grpc.v5.protos import ydb_common_pb2 as protos_dot_ydb__common__pb2
from ydb._grpc.v5.protos import ydb_issue_message_pb2 as protos_dot_ydb__issue__message__pb2
from ydb._grpc.v5.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from ydb._grpc.v5.protos import ydb_query_stats_pb2 as protos_dot_ydb__query__stats__pb2
from ydb._grpc.v5.protos import ydb_value_pb2 as protos_dot_ydb__value__pb2
from ydb._grpc.v5.protos import ydb_scheme_pb2 as protos_dot_ydb__scheme__pb2
from ydb._grpc.v5.protos import ydb_status_codes_pb2 as protos_dot_ydb__status__codes__pb2
from ydb._grpc.v5.protos import ydb_topic_pb2 as protos_dot_ydb__topic__pb2
from ydb._grpc.v5.protos import ydb_formats_pb2 as protos_dot_ydb__formats__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16protos/ydb_table.proto\x12\tYdb.Table\x1a#protos/annotations/validation.proto\x1a\x17protos/ydb_common.proto\x1a\x1eprotos/ydb_issue_message.proto\x1a\x1aprotos/ydb_operation.proto\x1a\x1cprotos/ydb_query_stats.proto\x1a\x16protos/ydb_value.proto\x1a\x17protos/ydb_scheme.proto\x1a\x1dprotos/ydb_status_codes.proto\x1a\x16protos/ydb_topic.proto\x1a\x18protos/ydb_formats.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"Q\n\x14\x43reateSessionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"E\n\x15\x43reateSessionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\")\n\x13\x43reateSessionResult\x12\x12\n\nsession_id\x18\x01 \x01(\t\"e\n\x14\x44\x65leteSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"E\n\x15\x44\x65leteSessionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\r\n\x0bGlobalIndex\"\x12\n\x10GlobalAsyncIndex\"\x13\n\x11GlobalUniqueIndex\"\xf7\x01\n\nTableIndex\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rindex_columns\x18\x02 \x03(\t\x12.\n\x0cglobal_index\x18\x03 \x01(\x0b\x32\x16.Ydb.Table.GlobalIndexH\x00\x12\x39\n\x12global_async_index\x18\x04 \x01(\x0b\x32\x1b.Ydb.Table.GlobalAsyncIndexH\x00\x12;\n\x13global_unique_index\x18\x06 \x01(\x0b\x32\x1c.Ydb.Table.GlobalUniqueIndexH\x00\x12\x14\n\x0c\x64\x61ta_columns\x18\x05 \x03(\tB\x06\n\x04type\"\x98\x03\n\x15TableIndexDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rindex_columns\x18\x02 \x03(\t\x12.\n\x0cglobal_index\x18\x03 \x01(\x0b\x32\x16.Ydb.Table.GlobalIndexH\x00\x12\x39\n\x12global_async_index\x18\x05 \x01(\x0b\x32\x1b.Ydb.Table.GlobalAsyncIndexH\x00\x12;\n\x13global_unique_index\x18\x08 \x01(\x0b\x32\x1c.Ydb.Table.GlobalUniqueIndexH\x00\x12\x37\n\x06status\x18\x04 \x01(\x0e\x32\'.Ydb.Table.TableIndexDescription.Status\x12\x14\n\x0c\x64\x61ta_columns\x18\x06 \x03(\t\x12\x12\n\nsize_bytes\x18\x07 \x01(\x04\"G\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cSTATUS_READY\x10\x01\x12\x13\n\x0fSTATUS_BUILDING\x10\x02\x42\x06\n\x04type\"\xdd\x01\n\x0fIndexBuildState\"\xc9\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSTATE_PREPARING\x10\x01\x12\x1a\n\x16STATE_TRANSFERING_DATA\x10\x02\x12\x12\n\x0eSTATE_APPLYING\x10\x03\x12\x0e\n\nSTATE_DONE\x10\x04\x12\x16\n\x12STATE_CANCELLATION\x10\x05\x12\x13\n\x0fSTATE_CANCELLED\x10\x06\x12\x13\n\x0fSTATE_REJECTION\x10\x07\x12\x12\n\x0eSTATE_REJECTED\x10\x08\"K\n\x15IndexBuildDescription\x12\x0c\n\x04path\x18\x01 \x01(\t\x12$\n\x05index\x18\x02 \x01(\x0b\x32\x15.Ydb.Table.TableIndex\"\x8e\x01\n\x12IndexBuildMetadata\x12\x35\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32 .Ydb.Table.IndexBuildDescription\x12/\n\x05state\x18\x02 \x01(\x0e\x32 .Ydb.Table.IndexBuildState.State\x12\x10\n\x08progress\x18\x03 \x01(\x02\"\x9a\x01\n\x0e\x43hangefeedMode\"\x87\x01\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x12\n\x0eMODE_KEYS_ONLY\x10\x01\x12\x10\n\x0cMODE_UPDATES\x10\x02\x12\x12\n\x0eMODE_NEW_IMAGE\x10\x03\x12\x12\n\x0eMODE_OLD_IMAGE\x10\x04\x12\x1b\n\x17MODE_NEW_AND_OLD_IMAGES\x10\x05\"\x81\x01\n\x10\x43hangefeedFormat\"m\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x46ORMAT_JSON\x10\x01\x12 \n\x1c\x46ORMAT_DYNAMODB_STREAMS_JSON\x10\x02\x12\x18\n\x14\x46ORMAT_DEBEZIUM_JSON\x10\x03\"\x8e\x04\n\nChangefeed\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x04mode\x18\x02 \x01(\x0e\x32\x1e.Ydb.Table.ChangefeedMode.Mode\x12\x32\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\".Ydb.Table.ChangefeedFormat.Format\x12\x33\n\x10retention_period\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1a\n\x12virtual_timestamps\x18\x05 \x01(\x08\x12\x14\n\x0cinitial_scan\x18\x06 \x01(\x08\x12R\n\nattributes\x18\x07 \x03(\x0b\x32%.Ydb.Table.Changefeed.AttributesEntryB\x17\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\xa2\xe6*\x07\n\x05\x08\x01\x10\x80 \x12\x1b\n\naws_region\x18\x08 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\x12?\n\x1cresolved_timestamps_interval\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x44\n\x1btopic_partitioning_settings\x18\n \x01(\x0b\x32\x1f.Ydb.Topic.PartitioningSettings\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x87\x04\n\x15\x43hangefeedDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x04mode\x18\x02 \x01(\x0e\x32\x1e.Ydb.Table.ChangefeedMode.Mode\x12\x32\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\".Ydb.Table.ChangefeedFormat.Format\x12\x35\n\x05state\x18\x04 \x01(\x0e\x32&.Ydb.Table.ChangefeedDescription.State\x12\x1a\n\x12virtual_timestamps\x18\x05 \x01(\x08\x12\x44\n\nattributes\x18\x06 \x03(\x0b\x32\x30.Ydb.Table.ChangefeedDescription.AttributesEntry\x12\x12\n\naws_region\x18\x07 \x01(\t\x12?\n\x1cresolved_timestamps_interval\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x11\n\rSTATE_ENABLED\x10\x01\x12\x12\n\x0eSTATE_DISABLED\x10\x02\x12\x16\n\x12STATE_INITIAL_SCAN\x10\x03\"\x1c\n\x0bStoragePool\x12\r\n\x05media\x18\x01 \x01(\t\"\xaa\x02\n\rStoragePolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\x12&\n\x06syslog\x18\x02 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12#\n\x03log\x18\x03 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12$\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12(\n\x08\x65xternal\x18\x05 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12/\n\x0ekeep_in_memory\x18\x06 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x36\n\x0f\x63olumn_families\x18\x07 \x03(\x0b\x32\x1d.Ydb.Table.ColumnFamilyPolicy\"\xb1\x02\n\x12\x43olumnFamilyPolicy\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12(\n\x08\x65xternal\x18\x03 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12/\n\x0ekeep_in_memory\x18\x04 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12>\n\x0b\x63ompression\x18\x05 \x01(\x0e\x32).Ydb.Table.ColumnFamilyPolicy.Compression\"L\n\x0b\x43ompression\x12\x1b\n\x17\x43OMPRESSION_UNSPECIFIED\x10\x00\x12\x10\n\x0cUNCOMPRESSED\x10\x01\x12\x0e\n\nCOMPRESSED\x10\x02\"\'\n\x10\x43ompactionPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\";\n\x12\x45xplicitPartitions\x12%\n\x0csplit_points\x18\x01 \x03(\x0b\x32\x0f.Ydb.TypedValue\"S\n\x0ePartitionStats\x12\x15\n\rrows_estimate\x18\x01 \x01(\x04\x12\x12\n\nstore_size\x18\x02 \x01(\x04\x12\x16\n\x0eleader_node_id\x18\x03 \x01(\r\"\xe9\x01\n\nTableStats\x12\x32\n\x0fpartition_stats\x18\x01 \x03(\x0b\x32\x19.Ydb.Table.PartitionStats\x12\x15\n\rrows_estimate\x18\x02 \x01(\x04\x12\x12\n\nstore_size\x18\x03 \x01(\x04\x12\x12\n\npartitions\x18\x04 \x01(\x04\x12\x31\n\rcreation_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x11modification_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xdc\x02\n\x12PartitioningPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\x12O\n\x11\x61uto_partitioning\x18\x02 \x01(\x0e\x32\x34.Ydb.Table.PartitioningPolicy.AutoPartitioningPolicy\x12\x1c\n\x12uniform_partitions\x18\x03 \x01(\x04H\x00\x12<\n\x13\x65xplicit_partitions\x18\x04 \x01(\x0b\x32\x1d.Ydb.Table.ExplicitPartitionsH\x00\"v\n\x16\x41utoPartitioningPolicy\x12(\n$AUTO_PARTITIONING_POLICY_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\x12\x0e\n\nAUTO_SPLIT\x10\x02\x12\x14\n\x10\x41UTO_SPLIT_MERGE\x10\x03\x42\x0c\n\npartitions\"&\n\x0f\x45xecutionPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\"\xb1\x01\n\x11ReplicationPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\x12\x16\n\x0ereplicas_count\x18\x02 \x01(\r\x12=\n\x1c\x63reate_per_availability_zone\x18\x03 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x30\n\x0f\x61llow_promotion\x18\x04 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\"$\n\rCachingPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\"\xeb\x02\n\x0cTableProfile\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\x12\x30\n\x0estorage_policy\x18\x02 \x01(\x0b\x32\x18.Ydb.Table.StoragePolicy\x12\x36\n\x11\x63ompaction_policy\x18\x03 \x01(\x0b\x32\x1b.Ydb.Table.CompactionPolicy\x12:\n\x13partitioning_policy\x18\x04 \x01(\x0b\x32\x1d.Ydb.Table.PartitioningPolicy\x12\x34\n\x10\x65xecution_policy\x18\x05 \x01(\x0b\x32\x1a.Ydb.Table.ExecutionPolicy\x12\x38\n\x12replication_policy\x18\x06 \x01(\x0b\x32\x1c.Ydb.Table.ReplicationPolicy\x12\x30\n\x0e\x63\x61\x63hing_policy\x18\x07 \x01(\x0b\x32\x18.Ydb.Table.CachingPolicy\"\xaa\x03\n\x13SequenceDescription\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tmin_value\x18\x02 \x01(\x12H\x01\x88\x01\x01\x12\x16\n\tmax_value\x18\x03 \x01(\x12H\x02\x88\x01\x01\x12\x18\n\x0bstart_value\x18\x04 \x01(\x12H\x03\x88\x01\x01\x12\x12\n\x05\x63\x61\x63he\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x16\n\tincrement\x18\x06 \x01(\x12H\x05\x88\x01\x01\x12\x12\n\x05\x63ycle\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12;\n\x07set_val\x18\x08 \x01(\x0b\x32%.Ydb.Table.SequenceDescription.SetValH\x07\x88\x01\x01\x1aV\n\x06SetVal\x12\x17\n\nnext_value\x18\x01 \x01(\x12H\x00\x88\x01\x01\x12\x16\n\tnext_used\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\r\n\x0b_next_valueB\x0c\n\n_next_usedB\x07\n\x05_nameB\x0c\n\n_min_valueB\x0c\n\n_max_valueB\x0e\n\x0c_start_valueB\x08\n\x06_cacheB\x0c\n\n_incrementB\x08\n\x06_cycleB\n\n\x08_set_val\"\xda\x01\n\nColumnMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x04type\x18\x02 \x01(\x0b\x32\t.Ydb.Type\x12\x0e\n\x06\x66\x61mily\x18\x03 \x01(\t\x12\x15\n\x08not_null\x18\x04 \x01(\x08H\x01\x88\x01\x01\x12\'\n\x0c\x66rom_literal\x18\x05 \x01(\x0b\x32\x0f.Ydb.TypedValueH\x00\x12\x37\n\rfrom_sequence\x18\x06 \x01(\x0b\x32\x1e.Ydb.Table.SequenceDescriptionH\x00\x42\x0f\n\rdefault_valueB\x0b\n\t_not_null\"O\n\x1a\x44\x61teTypeColumnModeSettings\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x1c\n\x14\x65xpire_after_seconds\x18\x02 \x01(\r\"\x8e\x02\n\x1fValueSinceUnixEpochModeSettings\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x44\n\x0b\x63olumn_unit\x18\x02 \x01(\x0e\x32/.Ydb.Table.ValueSinceUnixEpochModeSettings.Unit\x12\x1c\n\x14\x65xpire_after_seconds\x18\x03 \x01(\r\"r\n\x04Unit\x12\x14\n\x10UNIT_UNSPECIFIED\x10\x00\x12\x10\n\x0cUNIT_SECONDS\x10\x01\x12\x15\n\x11UNIT_MILLISECONDS\x10\x02\x12\x15\n\x11UNIT_MICROSECONDS\x10\x03\x12\x14\n\x10UNIT_NANOSECONDS\x10\x04\"\xc4\x01\n\x0bTtlSettings\x12\x41\n\x10\x64\x61te_type_column\x18\x01 \x01(\x0b\x32%.Ydb.Table.DateTypeColumnModeSettingsH\x00\x12L\n\x16value_since_unix_epoch\x18\x02 \x01(\x0b\x32*.Ydb.Table.ValueSinceUnixEpochModeSettingsH\x00\x12\x1c\n\x14run_interval_seconds\x18\x03 \x01(\rB\x06\n\x04mode\"\xda\x01\n\x0fStorageSettings\x12\x32\n\x12tablet_commit_log0\x18\x01 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12\x32\n\x12tablet_commit_log1\x18\x02 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12(\n\x08\x65xternal\x18\x04 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12\x35\n\x14store_external_blobs\x18\x05 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\"\x84\x02\n\x0c\x43olumnFamily\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12\x38\n\x0b\x63ompression\x18\x03 \x01(\x0e\x32#.Ydb.Table.ColumnFamily.Compression\x12/\n\x0ekeep_in_memory\x18\x04 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\"U\n\x0b\x43ompression\x12\x1b\n\x17\x43OMPRESSION_UNSPECIFIED\x10\x00\x12\x14\n\x10\x43OMPRESSION_NONE\x10\x01\x12\x13\n\x0f\x43OMPRESSION_LZ4\x10\x02\"\xf7\x01\n\x14PartitioningSettings\x12\x14\n\x0cpartition_by\x18\x01 \x03(\t\x12\x35\n\x14partitioning_by_size\x18\x02 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x19\n\x11partition_size_mb\x18\x03 \x01(\x04\x12\x35\n\x14partitioning_by_load\x18\x04 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x1c\n\x14min_partitions_count\x18\x06 \x01(\x04\x12\x1c\n\x14max_partitions_count\x18\x07 \x01(\x04J\x04\x08\x05\x10\x06\"C\n\x16\x41zReadReplicasSettings\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x13read_replicas_count\x18\x02 \x01(\x04\"_\n\x17\x43lusterReplicasSettings\x12\x44\n\x19\x61z_read_replicas_settings\x18\x02 \x03(\x0b\x32!.Ydb.Table.AzReadReplicasSettings\"t\n\x14ReadReplicasSettings\x12$\n\x1aper_az_read_replicas_count\x18\x01 \x01(\x04H\x00\x12$\n\x1a\x61ny_az_read_replicas_count\x18\x02 \x01(\x04H\x00\x42\n\n\x08settingsJ\x04\x08\x03\x10\x04\"\xaa\x07\n\x12\x43reateTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12&\n\x07\x63olumns\x18\x03 \x03(\x0b\x32\x15.Ydb.Table.ColumnMeta\x12\x13\n\x0bprimary_key\x18\x04 \x03(\t\x12(\n\x07profile\x18\x05 \x01(\x0b\x32\x17.Ydb.Table.TableProfile\x12\x39\n\x10operation_params\x18\x06 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12&\n\x07indexes\x18\x07 \x03(\x0b\x32\x15.Ydb.Table.TableIndex\x12,\n\x0cttl_settings\x18\x08 \x01(\x0b\x32\x16.Ydb.Table.TtlSettings\x12\x34\n\x10storage_settings\x18\t \x01(\x0b\x32\x1a.Ydb.Table.StorageSettings\x12\x30\n\x0f\x63olumn_families\x18\n \x03(\x0b\x32\x17.Ydb.Table.ColumnFamily\x12Z\n\nattributes\x18\x0b \x03(\x0b\x32-.Ydb.Table.CreateTableRequest.AttributesEntryB\x17\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\xa2\xe6*\x07\n\x05\x08\x01\x10\x80 \x12\x19\n\x11\x63ompaction_policy\x18\x0c \x01(\t\x12\x1c\n\x12uniform_partitions\x18\r \x01(\x04H\x00\x12:\n\x11partition_at_keys\x18\x0e \x01(\x0b\x32\x1d.Ydb.Table.ExplicitPartitionsH\x00\x12>\n\x15partitioning_settings\x18\x0f \x01(\x0b\x32\x1f.Ydb.Table.PartitioningSettings\x12\x31\n\x10key_bloom_filter\x18\x10 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12?\n\x16read_replicas_settings\x18\x11 \x01(\x0b\x32\x1f.Ydb.Table.ReadReplicasSettings\x12\x0f\n\x07tiering\x18\x12 \x01(\t\x12\x11\n\ttemporary\x18\x13 \x01(\x08\x12(\n\nstore_type\x18\x14 \x01(\x0e\x32\x14.Ydb.Table.StoreType\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\npartitions\"C\n\x13\x43reateTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"u\n\x10\x44ropTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x04 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParamsJ\x04\x08\x03\x10\x04\"A\n\x11\x44ropTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"]\n\x0fRenameIndexItem\x12\x13\n\x0bsource_name\x18\x01 \x01(\t\x12\x18\n\x10\x64\x65stination_name\x18\x02 \x01(\t\x12\x1b\n\x13replace_destination\x18\x03 \x01(\x08\"\x95\t\n\x11\x41lterTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12*\n\x0b\x61\x64\x64_columns\x18\x03 \x03(\x0b\x32\x15.Ydb.Table.ColumnMeta\x12\x14\n\x0c\x64rop_columns\x18\x04 \x03(\t\x12\x39\n\x10operation_params\x18\x05 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12,\n\ralter_columns\x18\x06 \x03(\x0b\x32\x15.Ydb.Table.ColumnMeta\x12\x32\n\x10set_ttl_settings\x18\x07 \x01(\x0b\x32\x16.Ydb.Table.TtlSettingsH\x00\x12\x33\n\x11\x64rop_ttl_settings\x18\x08 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12*\n\x0b\x61\x64\x64_indexes\x18\t \x03(\x0b\x32\x15.Ydb.Table.TableIndex\x12\x14\n\x0c\x64rop_indexes\x18\n \x03(\t\x12:\n\x16\x61lter_storage_settings\x18\x0b \x01(\x0b\x32\x1a.Ydb.Table.StorageSettings\x12\x34\n\x13\x61\x64\x64_column_families\x18\x0c \x03(\x0b\x32\x17.Ydb.Table.ColumnFamily\x12\x36\n\x15\x61lter_column_families\x18\r \x03(\x0b\x32\x17.Ydb.Table.ColumnFamily\x12`\n\x10\x61lter_attributes\x18\x0e \x03(\x0b\x32\x31.Ydb.Table.AlterTableRequest.AlterAttributesEntryB\x13\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\xa2\xe6*\x03\x18\x80 \x12\x1d\n\x15set_compaction_policy\x18\x0f \x01(\t\x12\x44\n\x1b\x61lter_partitioning_settings\x18\x10 \x01(\x0b\x32\x1f.Ydb.Table.PartitioningSettings\x12\x35\n\x14set_key_bloom_filter\x18\x11 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x43\n\x1aset_read_replicas_settings\x18\x12 \x01(\x0b\x32\x1f.Ydb.Table.ReadReplicasSettings\x12.\n\x0f\x61\x64\x64_changefeeds\x18\x13 \x03(\x0b\x32\x15.Ydb.Table.Changefeed\x12\x18\n\x10\x64rop_changefeeds\x18\x14 \x03(\t\x12\x32\n\x0erename_indexes\x18\x15 \x03(\x0b\x32\x1a.Ydb.Table.RenameIndexItem\x12\x15\n\x0bset_tiering\x18\x16 \x01(\tH\x01\x12.\n\x0c\x64rop_tiering\x18\x17 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x1a\x36\n\x14\x41lterAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\nttl_actionB\x10\n\x0etiering_action\"B\n\x12\x41lterTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x90\x01\n\x10\x43opyTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x13\n\x0bsource_path\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x03 \x01(\t\x12\x39\n\x10operation_params\x18\x04 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"A\n\x11\x43opyTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"T\n\rCopyTableItem\x12\x13\n\x0bsource_path\x18\x01 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x02 \x01(\t\x12\x14\n\x0comit_indexes\x18\x03 \x01(\x08\"\x8c\x01\n\x11\x43opyTablesRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12(\n\x06tables\x18\x03 \x03(\x0b\x32\x18.Ydb.Table.CopyTableItem\"B\n\x12\x43opyTablesResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"]\n\x0fRenameTableItem\x12\x13\n\x0bsource_path\x18\x01 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x02 \x01(\t\x12\x1b\n\x13replace_destination\x18\x03 \x01(\x08\"\x90\x01\n\x13RenameTablesRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12*\n\x06tables\x18\x03 \x03(\x0b\x32\x1a.Ydb.Table.RenameTableItem\"D\n\x14RenameTablesResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xf5\x01\n\x14\x44\x65scribeTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x04 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12 \n\x18include_shard_key_bounds\x18\x05 \x01(\x08\x12\x1b\n\x13include_table_stats\x18\x06 \x01(\x08\x12\x1f\n\x17include_partition_stats\x18\x07 \x01(\x08\x12 \n\x18include_shard_nodes_info\x18\t \x01(\x08\"E\n\x15\x44\x65scribeTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xc9\x06\n\x13\x44\x65scribeTableResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\x12&\n\x07\x63olumns\x18\x02 \x03(\x0b\x32\x15.Ydb.Table.ColumnMeta\x12\x13\n\x0bprimary_key\x18\x03 \x03(\t\x12)\n\x10shard_key_bounds\x18\x04 \x03(\x0b\x32\x0f.Ydb.TypedValue\x12\x31\n\x07indexes\x18\x05 \x03(\x0b\x32 .Ydb.Table.TableIndexDescription\x12*\n\x0btable_stats\x18\x06 \x01(\x0b\x32\x15.Ydb.Table.TableStats\x12,\n\x0cttl_settings\x18\x07 \x01(\x0b\x32\x16.Ydb.Table.TtlSettings\x12\x34\n\x10storage_settings\x18\x08 \x01(\x0b\x32\x1a.Ydb.Table.StorageSettings\x12\x30\n\x0f\x63olumn_families\x18\t \x03(\x0b\x32\x17.Ydb.Table.ColumnFamily\x12\x42\n\nattributes\x18\n \x03(\x0b\x32..Ydb.Table.DescribeTableResult.AttributesEntry\x12>\n\x15partitioning_settings\x18\x0c \x01(\x0b\x32\x1f.Ydb.Table.PartitioningSettings\x12\x31\n\x10key_bloom_filter\x18\r \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12?\n\x16read_replicas_settings\x18\x0e \x01(\x0b\x32\x1f.Ydb.Table.ReadReplicasSettings\x12\x35\n\x0b\x63hangefeeds\x18\x0f \x03(\x0b\x32 .Ydb.Table.ChangefeedDescription\x12\x0f\n\x07tiering\x18\x10 \x01(\t\x12\x11\n\ttemporary\x18\x11 \x01(\x08\x12(\n\nstore_type\x18\x12 \x01(\x0e\x32\x14.Ydb.Table.StoreType\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x0b\x10\x0c\"2\n\x05Query\x12\x12\n\x08yql_text\x18\x01 \x01(\tH\x00\x12\x0c\n\x02id\x18\x02 \x01(\tH\x00\x42\x07\n\x05query\"\x1a\n\x18SerializableModeSettings\"6\n\x12OnlineModeSettings\x12 \n\x18\x61llow_inconsistent_reads\x18\x01 \x01(\x08\"\x13\n\x11StaleModeSettings\"\x16\n\x14SnapshotModeSettings\"\x18\n\x16SnapshotRWModeSettings\"\xdd\x02\n\x13TransactionSettings\x12\x46\n\x17serializable_read_write\x18\x01 \x01(\x0b\x32#.Ydb.Table.SerializableModeSettingsH\x00\x12\x39\n\x10online_read_only\x18\x02 \x01(\x0b\x32\x1d.Ydb.Table.OnlineModeSettingsH\x00\x12\x37\n\x0fstale_read_only\x18\x03 \x01(\x0b\x32\x1c.Ydb.Table.StaleModeSettingsH\x00\x12=\n\x12snapshot_read_only\x18\x04 \x01(\x0b\x32\x1f.Ydb.Table.SnapshotModeSettingsH\x00\x12@\n\x13snapshot_read_write\x18\x05 \x01(\x0b\x32!.Ydb.Table.SnapshotRWModeSettingsH\x00\x42\t\n\x07tx_mode\"{\n\x12TransactionControl\x12\x0f\n\x05tx_id\x18\x01 \x01(\tH\x00\x12\x32\n\x08\x62\x65gin_tx\x18\x02 \x01(\x0b\x32\x1e.Ydb.Table.TransactionSettingsH\x00\x12\x11\n\tcommit_tx\x18\n \x01(\x08\x42\r\n\x0btx_selector\")\n\x10QueryCachePolicy\x12\x15\n\rkeep_in_cache\x18\x01 \x01(\x08\"\xb1\x01\n\x14QueryStatsCollection\"\x98\x01\n\x04Mode\x12 \n\x1cSTATS_COLLECTION_UNSPECIFIED\x10\x00\x12\x19\n\x15STATS_COLLECTION_NONE\x10\x01\x12\x1a\n\x16STATS_COLLECTION_BASIC\x10\x02\x12\x19\n\x15STATS_COLLECTION_FULL\x10\x03\x12\x1c\n\x18STATS_COLLECTION_PROFILE\x10\x04\"\xbe\x03\n\x17\x45xecuteDataQueryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x31\n\ntx_control\x18\x02 \x01(\x0b\x32\x1d.Ydb.Table.TransactionControl\x12\x1f\n\x05query\x18\x03 \x01(\x0b\x32\x10.Ydb.Table.Query\x12\x46\n\nparameters\x18\x04 \x03(\x0b\x32\x32.Ydb.Table.ExecuteDataQueryRequest.ParametersEntry\x12\x37\n\x12query_cache_policy\x18\x05 \x01(\x0b\x32\x1b.Ydb.Table.QueryCachePolicy\x12\x39\n\x10operation_params\x18\x06 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12;\n\rcollect_stats\x18\x07 \x01(\x0e\x32$.Ydb.Table.QueryStatsCollection.Mode\x1a\x42\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01\"H\n\x18\x45xecuteDataQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"|\n\x19\x45xecuteSchemeQueryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x10\n\x08yql_text\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"J\n\x1a\x45xecuteSchemeQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x1d\n\x0fTransactionMeta\x12\n\n\x02id\x18\x01 \x01(\t\"\x9f\x01\n\tQueryMeta\x12\n\n\x02id\x18\x01 \x01(\t\x12\x43\n\x10parameters_types\x18\x02 \x03(\x0b\x32).Ydb.Table.QueryMeta.ParametersTypesEntry\x1a\x41\n\x14ParametersTypesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x18\n\x05value\x18\x02 \x01(\x0b\x32\t.Ydb.Type:\x02\x38\x01\"\xc1\x01\n\x12\x45xecuteQueryResult\x12#\n\x0bresult_sets\x18\x01 \x03(\x0b\x32\x0e.Ydb.ResultSet\x12+\n\x07tx_meta\x18\x02 \x01(\x0b\x32\x1a.Ydb.Table.TransactionMeta\x12(\n\nquery_meta\x18\x03 \x01(\x0b\x32\x14.Ydb.Table.QueryMeta\x12/\n\x0bquery_stats\x18\x04 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStats\"\x9c\x01\n\x17\x45xplainDataQueryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x10\n\x08yql_text\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12 \n\x18\x63ollect_full_diagnostics\x18\x04 \x01(\x08\"H\n\x18\x45xplainDataQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"[\n\x12\x45xplainQueryResult\x12\x11\n\tquery_ast\x18\x01 \x01(\t\x12\x12\n\nquery_plan\x18\x02 \x01(\t\x12\x1e\n\x16query_full_diagnostics\x18\x03 \x01(\t\"z\n\x17PrepareDataQueryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x10\n\x08yql_text\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"H\n\x18PrepareDataQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xb7\x01\n\x12PrepareQueryResult\x12\x10\n\x08query_id\x18\x01 \x01(\t\x12L\n\x10parameters_types\x18\x02 \x03(\x0b\x32\x32.Ydb.Table.PrepareQueryResult.ParametersTypesEntry\x1a\x41\n\x14ParametersTypesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x18\n\x05value\x18\x02 \x01(\x0b\x32\t.Ydb.Type:\x02\x38\x01\"a\n\x10KeepAliveRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"A\n\x11KeepAliveResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xb7\x01\n\x0fKeepAliveResult\x12@\n\x0esession_status\x18\x01 \x01(\x0e\x32(.Ydb.Table.KeepAliveResult.SessionStatus\"b\n\rSessionStatus\x12\x1e\n\x1aSESSION_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14SESSION_STATUS_READY\x10\x01\x12\x17\n\x13SESSION_STATUS_BUSY\x10\x02\"\x9d\x01\n\x17\x42\x65ginTransactionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x33\n\x0btx_settings\x18\x02 \x01(\x0b\x32\x1e.Ydb.Table.TransactionSettings\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"H\n\x18\x42\x65ginTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"E\n\x16\x42\x65ginTransactionResult\x12+\n\x07tx_meta\x18\x01 \x01(\x0b\x32\x1a.Ydb.Table.TransactionMeta\"\xb5\x01\n\x18\x43ommitTransactionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\r\n\x05tx_id\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12;\n\rcollect_stats\x18\x04 \x01(\x0e\x32$.Ydb.Table.QueryStatsCollection.Mode\"I\n\x19\x43ommitTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"J\n\x17\x43ommitTransactionResult\x12/\n\x0bquery_stats\x18\x01 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStats\"z\n\x1aRollbackTransactionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\r\n\x05tx_id\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"K\n\x1bRollbackTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x98\x01\n\x18StoragePolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\x06labels\x18\x02 \x03(\x0b\x32/.Ydb.Table.StoragePolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9e\x01\n\x1b\x43ompactionPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x42\n\x06labels\x18\x02 \x03(\x0b\x32\x32.Ydb.Table.CompactionPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa2\x01\n\x1dPartitioningPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x44\n\x06labels\x18\x02 \x03(\x0b\x32\x34.Ydb.Table.PartitioningPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x01\n\x1a\x45xecutionPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x41\n\x06labels\x18\x02 \x03(\x0b\x32\x31.Ydb.Table.ExecutionPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa0\x01\n\x1cReplicationPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x43\n\x06labels\x18\x02 \x03(\x0b\x32\x33.Ydb.Table.ReplicationPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x98\x01\n\x18\x43\x61\x63hingPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\x06labels\x18\x02 \x03(\x0b\x32/.Ydb.Table.CachingPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbe\x04\n\x17TableProfileDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12>\n\x06labels\x18\x02 \x03(\x0b\x32..Ydb.Table.TableProfileDescription.LabelsEntry\x12\x1e\n\x16\x64\x65\x66\x61ult_storage_policy\x18\x03 \x01(\t\x12 \n\x18\x61llowed_storage_policies\x18\x04 \x03(\t\x12!\n\x19\x64\x65\x66\x61ult_compaction_policy\x18\x05 \x01(\t\x12#\n\x1b\x61llowed_compaction_policies\x18\x06 \x03(\t\x12#\n\x1b\x64\x65\x66\x61ult_partitioning_policy\x18\x07 \x01(\t\x12%\n\x1d\x61llowed_partitioning_policies\x18\x08 \x03(\t\x12 \n\x18\x64\x65\x66\x61ult_execution_policy\x18\t \x01(\t\x12\"\n\x1a\x61llowed_execution_policies\x18\n \x03(\t\x12\"\n\x1a\x64\x65\x66\x61ult_replication_policy\x18\x0b \x01(\t\x12$\n\x1c\x61llowed_replication_policies\x18\x0c \x03(\t\x12\x1e\n\x16\x64\x65\x66\x61ult_caching_policy\x18\r \x01(\t\x12 \n\x18\x61llowed_caching_policies\x18\x0e \x03(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"X\n\x1b\x44\x65scribeTableOptionsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"L\n\x1c\x44\x65scribeTableOptionsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x99\x04\n\x1a\x44\x65scribeTableOptionsResult\x12\x41\n\x15table_profile_presets\x18\x01 \x03(\x0b\x32\".Ydb.Table.TableProfileDescription\x12\x43\n\x16storage_policy_presets\x18\x02 \x03(\x0b\x32#.Ydb.Table.StoragePolicyDescription\x12I\n\x19\x63ompaction_policy_presets\x18\x03 \x03(\x0b\x32&.Ydb.Table.CompactionPolicyDescription\x12M\n\x1bpartitioning_policy_presets\x18\x04 \x03(\x0b\x32(.Ydb.Table.PartitioningPolicyDescription\x12G\n\x18\x65xecution_policy_presets\x18\x05 \x03(\x0b\x32%.Ydb.Table.ExecutionPolicyDescription\x12K\n\x1areplication_policy_presets\x18\x06 \x03(\x0b\x32\'.Ydb.Table.ReplicationPolicyDescription\x12\x43\n\x16\x63\x61\x63hing_policy_presets\x18\x07 \x03(\x0b\x32#.Ydb.Table.CachingPolicyDescription\"\xc0\x01\n\x08KeyRange\x12\"\n\x07greater\x18\x01 \x01(\x0b\x32\x0f.Ydb.TypedValueH\x00\x12+\n\x10greater_or_equal\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValueH\x00\x12\x1f\n\x04less\x18\x03 \x01(\x0b\x32\x0f.Ydb.TypedValueH\x01\x12(\n\rless_or_equal\x18\x04 \x01(\x0b\x32\x0f.Ydb.TypedValueH\x01\x42\x0c\n\nfrom_boundB\n\n\x08to_bound\"\xb8\x02\n\x10ReadTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12&\n\tkey_range\x18\x03 \x01(\x0b\x32\x13.Ydb.Table.KeyRange\x12\x0f\n\x07\x63olumns\x18\x04 \x03(\t\x12\x0f\n\x07ordered\x18\x05 \x01(\x08\x12\x11\n\trow_limit\x18\x06 \x01(\x04\x12-\n\x0cuse_snapshot\x18\x07 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x19\n\x11\x62\x61tch_limit_bytes\x18\x08 \x01(\x04\x12\x18\n\x10\x62\x61tch_limit_rows\x18\t \x01(\x04\x12\x41\n return_not_null_data_as_optional\x18\n \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\"\xbc\x01\n\x11ReadTableResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\'\n\x08snapshot\x18\x04 \x01(\x0b\x32\x15.Ydb.VirtualTimestamp\x12*\n\x06result\x18\x03 \x01(\x0b\x32\x1a.Ydb.Table.ReadTableResult\"5\n\x0fReadTableResult\x12\"\n\nresult_set\x18\x01 \x01(\x0b\x32\x0e.Ydb.ResultSet\"c\n\x0fReadRowsRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x1d\n\x04keys\x18\x03 \x01(\x0b\x32\x0f.Ydb.TypedValue\x12\x0f\n\x07\x63olumns\x18\x04 \x03(\t\"\x8a\x01\n\x10ReadRowsResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\"\n\nresult_set\x18\x03 \x01(\x0b\x32\x0e.Ydb.ResultSet\"\x8d\x02\n\x11\x42ulkUpsertRequest\x12\r\n\x05table\x18\x01 \x01(\t\x12\x1d\n\x04rows\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12?\n\x14\x61rrow_batch_settings\x18\x07 \x01(\x0b\x32\x1f.Ydb.Formats.ArrowBatchSettingsH\x00\x12\x30\n\x0c\x63sv_settings\x18\x08 \x01(\x0b\x32\x18.Ydb.Formats.CsvSettingsH\x00\x12\r\n\x04\x64\x61ta\x18\xe8\x07 \x01(\x0c\x42\r\n\x0b\x64\x61ta_format\"B\n\x12\x42ulkUpsertResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x12\n\x10\x42ulkUpsertResult\"\xb3\x03\n\x17\x45xecuteScanQueryRequest\x12\x1f\n\x05query\x18\x03 \x01(\x0b\x32\x10.Ydb.Table.Query\x12\x46\n\nparameters\x18\x04 \x03(\x0b\x32\x32.Ydb.Table.ExecuteScanQueryRequest.ParametersEntry\x12\x35\n\x04mode\x18\x06 \x01(\x0e\x32\'.Ydb.Table.ExecuteScanQueryRequest.Mode\x12;\n\rcollect_stats\x18\x08 \x01(\x0e\x32$.Ydb.Table.QueryStatsCollection.Mode\x12 \n\x18\x63ollect_full_diagnostics\x18\t \x01(\x08\x1a\x42\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01\"=\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x10\n\x0cMODE_EXPLAIN\x10\x01\x12\r\n\tMODE_EXEC\x10\x03J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x05\x10\x06J\x04\x08\x07\x10\x08\"\xaf\x01\n\x1f\x45xecuteScanQueryPartialResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x38\n\x06result\x18\x03 \x01(\x0b\x32(.Ydb.Table.ExecuteScanQueryPartialResult\"\xac\x01\n\x1d\x45xecuteScanQueryPartialResult\x12\"\n\nresult_set\x18\x01 \x01(\x0b\x32\x0e.Ydb.ResultSet\x12/\n\x0bquery_stats\x18\x06 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStats\x12\x1e\n\x16query_full_diagnostics\x18\x07 \x01(\tJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06*R\n\tStoreType\x12\x1a\n\x16STORE_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0eSTORE_TYPE_ROW\x10\x01\x12\x15\n\x11STORE_TYPE_COLUMN\x10\x02\x42S\n\x14tech.ydb.proto.tableZ8github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Table\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.ydb_table_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024tech.ydb.proto.tableZ8github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Table\370\001\001'
  _CHANGEFEED_ATTRIBUTESENTRY._options = None
  _CHANGEFEED_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _CHANGEFEED.fields_by_name['attributes']._options = None
  _CHANGEFEED.fields_by_name['attributes']._serialized_options = b'\252\346*\010\n\006\n\004\010\001\020d\242\346*\007\n\005\010\001\020\200 '
  _CHANGEFEED.fields_by_name['aws_region']._options = None
  _CHANGEFEED.fields_by_name['aws_region']._serialized_options = b'\242\346*\003\030\200\001'
  _CHANGEFEEDDESCRIPTION_ATTRIBUTESENTRY._options = None
  _CHANGEFEEDDESCRIPTION_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _CREATETABLEREQUEST_ATTRIBUTESENTRY._options = None
  _CREATETABLEREQUEST_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _CREATETABLEREQUEST.fields_by_name['attributes']._options = None
  _CREATETABLEREQUEST.fields_by_name['attributes']._serialized_options = b'\252\346*\010\n\006\n\004\010\001\020d\242\346*\007\n\005\010\001\020\200 '
  _ALTERTABLEREQUEST_ALTERATTRIBUTESENTRY._options = None
  _ALTERTABLEREQUEST_ALTERATTRIBUTESENTRY._serialized_options = b'8\001'
  _ALTERTABLEREQUEST.fields_by_name['alter_attributes']._options = None
  _ALTERTABLEREQUEST.fields_by_name['alter_attributes']._serialized_options = b'\252\346*\010\n\006\n\004\010\001\020d\242\346*\003\030\200 '
  _DESCRIBETABLERESULT_ATTRIBUTESENTRY._options = None
  _DESCRIBETABLERESULT_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _EXECUTEDATAQUERYREQUEST_PARAMETERSENTRY._options = None
  _EXECUTEDATAQUERYREQUEST_PARAMETERSENTRY._serialized_options = b'8\001'
  _QUERYMETA_PARAMETERSTYPESENTRY._options = None
  _QUERYMETA_PARAMETERSTYPESENTRY._serialized_options = b'8\001'
  _PREPAREQUERYRESULT_PARAMETERSTYPESENTRY._options = None
  _PREPAREQUERYRESULT_PARAMETERSTYPESENTRY._serialized_options = b'8\001'
  _STORAGEPOLICYDESCRIPTION_LABELSENTRY._options = None
  _STORAGEPOLICYDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _COMPACTIONPOLICYDESCRIPTION_LABELSENTRY._options = None
  _COMPACTIONPOLICYDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _PARTITIONINGPOLICYDESCRIPTION_LABELSENTRY._options = None
  _PARTITIONINGPOLICYDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _EXECUTIONPOLICYDESCRIPTION_LABELSENTRY._options = None
  _EXECUTIONPOLICYDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _REPLICATIONPOLICYDESCRIPTION_LABELSENTRY._options = None
  _REPLICATIONPOLICYDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _CACHINGPOLICYDESCRIPTION_LABELSENTRY._options = None
  _CACHINGPOLICYDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _TABLEPROFILEDESCRIPTION_LABELSENTRY._options = None
  _TABLEPROFILEDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _EXECUTESCANQUERYREQUEST_PARAMETERSENTRY._options = None
  _EXECUTESCANQUERYREQUEST_PARAMETERSENTRY._serialized_options = b'8\001'
  _STORETYPE._serialized_start=20382
  _STORETYPE._serialized_end=20464
  _CREATESESSIONREQUEST._serialized_start=413
  _CREATESESSIONREQUEST._serialized_end=494
  _CREATESESSIONRESPONSE._serialized_start=496
  _CREATESESSIONRESPONSE._serialized_end=565
  _CREATESESSIONRESULT._serialized_start=567
  _CREATESESSIONRESULT._serialized_end=608
  _DELETESESSIONREQUEST._serialized_start=610
  _DELETESESSIONREQUEST._serialized_end=711
  _DELETESESSIONRESPONSE._serialized_start=713
  _DELETESESSIONRESPONSE._serialized_end=782
  _GLOBALINDEX._serialized_start=784
  _GLOBALINDEX._serialized_end=797
  _GLOBALASYNCINDEX._serialized_start=799
  _GLOBALASYNCINDEX._serialized_end=817
  _GLOBALUNIQUEINDEX._serialized_start=819
  _GLOBALUNIQUEINDEX._serialized_end=838
  _TABLEINDEX._serialized_start=841
  _TABLEINDEX._serialized_end=1088
  _TABLEINDEXDESCRIPTION._serialized_start=1091
  _TABLEINDEXDESCRIPTION._serialized_end=1499
  _TABLEINDEXDESCRIPTION_STATUS._serialized_start=1420
  _TABLEINDEXDESCRIPTION_STATUS._serialized_end=1491
  _INDEXBUILDSTATE._serialized_start=1502
  _INDEXBUILDSTATE._serialized_end=1723
  _INDEXBUILDSTATE_STATE._serialized_start=1522
  _INDEXBUILDSTATE_STATE._serialized_end=1723
  _INDEXBUILDDESCRIPTION._serialized_start=1725
  _INDEXBUILDDESCRIPTION._serialized_end=1800
  _INDEXBUILDMETADATA._serialized_start=1803
  _INDEXBUILDMETADATA._serialized_end=1945
  _CHANGEFEEDMODE._serialized_start=1948
  _CHANGEFEEDMODE._serialized_end=2102
  _CHANGEFEEDMODE_MODE._serialized_start=1967
  _CHANGEFEEDMODE_MODE._serialized_end=2102
  _CHANGEFEEDFORMAT._serialized_start=2105
  _CHANGEFEEDFORMAT._serialized_end=2234
  _CHANGEFEEDFORMAT_FORMAT._serialized_start=2125
  _CHANGEFEEDFORMAT_FORMAT._serialized_end=2234
  _CHANGEFEED._serialized_start=2237
  _CHANGEFEED._serialized_end=2763
  _CHANGEFEED_ATTRIBUTESENTRY._serialized_start=2714
  _CHANGEFEED_ATTRIBUTESENTRY._serialized_end=2763
  _CHANGEFEEDDESCRIPTION._serialized_start=2766
  _CHANGEFEEDDESCRIPTION._serialized_end=3285
  _CHANGEFEEDDESCRIPTION_ATTRIBUTESENTRY._serialized_start=2714
  _CHANGEFEEDDESCRIPTION_ATTRIBUTESENTRY._serialized_end=2763
  _CHANGEFEEDDESCRIPTION_STATE._serialized_start=3192
  _CHANGEFEEDDESCRIPTION_STATE._serialized_end=3285
  _STORAGEPOOL._serialized_start=3287
  _STORAGEPOOL._serialized_end=3315
  _STORAGEPOLICY._serialized_start=3318
  _STORAGEPOLICY._serialized_end=3616
  _COLUMNFAMILYPOLICY._serialized_start=3619
  _COLUMNFAMILYPOLICY._serialized_end=3924
  _COLUMNFAMILYPOLICY_COMPRESSION._serialized_start=3848
  _COLUMNFAMILYPOLICY_COMPRESSION._serialized_end=3924
  _COMPACTIONPOLICY._serialized_start=3926
  _COMPACTIONPOLICY._serialized_end=3965
  _EXPLICITPARTITIONS._serialized_start=3967
  _EXPLICITPARTITIONS._serialized_end=4026
  _PARTITIONSTATS._serialized_start=4028
  _PARTITIONSTATS._serialized_end=4111
  _TABLESTATS._serialized_start=4114
  _TABLESTATS._serialized_end=4347
  _PARTITIONINGPOLICY._serialized_start=4350
  _PARTITIONINGPOLICY._serialized_end=4698
  _PARTITIONINGPOLICY_AUTOPARTITIONINGPOLICY._serialized_start=4566
  _PARTITIONINGPOLICY_AUTOPARTITIONINGPOLICY._serialized_end=4684
  _EXECUTIONPOLICY._serialized_start=4700
  _EXECUTIONPOLICY._serialized_end=4738
  _REPLICATIONPOLICY._serialized_start=4741
  _REPLICATIONPOLICY._serialized_end=4918
  _CACHINGPOLICY._serialized_start=4920
  _CACHINGPOLICY._serialized_end=4956
  _TABLEPROFILE._serialized_start=4959
  _TABLEPROFILE._serialized_end=5322
  _SEQUENCEDESCRIPTION._serialized_start=5325
  _SEQUENCEDESCRIPTION._serialized_end=5751
  _SEQUENCEDESCRIPTION_SETVAL._serialized_start=5566
  _SEQUENCEDESCRIPTION_SETVAL._serialized_end=5652
  _COLUMNMETA._serialized_start=5754
  _COLUMNMETA._serialized_end=5972
  _DATETYPECOLUMNMODESETTINGS._serialized_start=5974
  _DATETYPECOLUMNMODESETTINGS._serialized_end=6053
  _VALUESINCEUNIXEPOCHMODESETTINGS._serialized_start=6056
  _VALUESINCEUNIXEPOCHMODESETTINGS._serialized_end=6326
  _VALUESINCEUNIXEPOCHMODESETTINGS_UNIT._serialized_start=6212
  _VALUESINCEUNIXEPOCHMODESETTINGS_UNIT._serialized_end=6326
  _TTLSETTINGS._serialized_start=6329
  _TTLSETTINGS._serialized_end=6525
  _STORAGESETTINGS._serialized_start=6528
  _STORAGESETTINGS._serialized_end=6746
  _COLUMNFAMILY._serialized_start=6749
  _COLUMNFAMILY._serialized_end=7009
  _COLUMNFAMILY_COMPRESSION._serialized_start=6924
  _COLUMNFAMILY_COMPRESSION._serialized_end=7009
  _PARTITIONINGSETTINGS._serialized_start=7012
  _PARTITIONINGSETTINGS._serialized_end=7259
  _AZREADREPLICASSETTINGS._serialized_start=7261
  _AZREADREPLICASSETTINGS._serialized_end=7328
  _CLUSTERREPLICASSETTINGS._serialized_start=7330
  _CLUSTERREPLICASSETTINGS._serialized_end=7425
  _READREPLICASSETTINGS._serialized_start=7427
  _READREPLICASSETTINGS._serialized_end=7543
  _CREATETABLEREQUEST._serialized_start=7546
  _CREATETABLEREQUEST._serialized_end=8484
  _CREATETABLEREQUEST_ATTRIBUTESENTRY._serialized_start=2714
  _CREATETABLEREQUEST_ATTRIBUTESENTRY._serialized_end=2763
  _CREATETABLERESPONSE._serialized_start=8486
  _CREATETABLERESPONSE._serialized_end=8553
  _DROPTABLEREQUEST._serialized_start=8555
  _DROPTABLEREQUEST._serialized_end=8672
  _DROPTABLERESPONSE._serialized_start=8674
  _DROPTABLERESPONSE._serialized_end=8739
  _RENAMEINDEXITEM._serialized_start=8741
  _RENAMEINDEXITEM._serialized_end=8834
  _ALTERTABLEREQUEST._serialized_start=8837
  _ALTERTABLEREQUEST._serialized_end=10010
  _ALTERTABLEREQUEST_ALTERATTRIBUTESENTRY._serialized_start=9924
  _ALTERTABLEREQUEST_ALTERATTRIBUTESENTRY._serialized_end=9978
  _ALTERTABLERESPONSE._serialized_start=10012
  _ALTERTABLERESPONSE._serialized_end=10078
  _COPYTABLEREQUEST._serialized_start=10081
  _COPYTABLEREQUEST._serialized_end=10225
  _COPYTABLERESPONSE._serialized_start=10227
  _COPYTABLERESPONSE._serialized_end=10292
  _COPYTABLEITEM._serialized_start=10294
  _COPYTABLEITEM._serialized_end=10378
  _COPYTABLESREQUEST._serialized_start=10381
  _COPYTABLESREQUEST._serialized_end=10521
  _COPYTABLESRESPONSE._serialized_start=10523
  _COPYTABLESRESPONSE._serialized_end=10589
  _RENAMETABLEITEM._serialized_start=10591
  _RENAMETABLEITEM._serialized_end=10684
  _RENAMETABLESREQUEST._serialized_start=10687
  _RENAMETABLESREQUEST._serialized_end=10831
  _RENAMETABLESRESPONSE._serialized_start=10833
  _RENAMETABLESRESPONSE._serialized_end=10901
  _DESCRIBETABLEREQUEST._serialized_start=10904
  _DESCRIBETABLEREQUEST._serialized_end=11149
  _DESCRIBETABLERESPONSE._serialized_start=11151
  _DESCRIBETABLERESPONSE._serialized_end=11220
  _DESCRIBETABLERESULT._serialized_start=11223
  _DESCRIBETABLERESULT._serialized_end=12064
  _DESCRIBETABLERESULT_ATTRIBUTESENTRY._serialized_start=2714
  _DESCRIBETABLERESULT_ATTRIBUTESENTRY._serialized_end=2763
  _QUERY._serialized_start=12066
  _QUERY._serialized_end=12116
  _SERIALIZABLEMODESETTINGS._serialized_start=12118
  _SERIALIZABLEMODESETTINGS._serialized_end=12144
  _ONLINEMODESETTINGS._serialized_start=12146
  _ONLINEMODESETTINGS._serialized_end=12200
  _STALEMODESETTINGS._serialized_start=12202
  _STALEMODESETTINGS._serialized_end=12221
  _SNAPSHOTMODESETTINGS._serialized_start=12223
  _SNAPSHOTMODESETTINGS._serialized_end=12245
  _SNAPSHOTRWMODESETTINGS._serialized_start=12247
  _SNAPSHOTRWMODESETTINGS._serialized_end=12271
  _TRANSACTIONSETTINGS._serialized_start=12274
  _TRANSACTIONSETTINGS._serialized_end=12623
  _TRANSACTIONCONTROL._serialized_start=12625
  _TRANSACTIONCONTROL._serialized_end=12748
  _QUERYCACHEPOLICY._serialized_start=12750
  _QUERYCACHEPOLICY._serialized_end=12791
  _QUERYSTATSCOLLECTION._serialized_start=12794
  _QUERYSTATSCOLLECTION._serialized_end=12971
  _QUERYSTATSCOLLECTION_MODE._serialized_start=12819
  _QUERYSTATSCOLLECTION_MODE._serialized_end=12971
  _EXECUTEDATAQUERYREQUEST._serialized_start=12974
  _EXECUTEDATAQUERYREQUEST._serialized_end=13420
  _EXECUTEDATAQUERYREQUEST_PARAMETERSENTRY._serialized_start=13354
  _EXECUTEDATAQUERYREQUEST_PARAMETERSENTRY._serialized_end=13420
  _EXECUTEDATAQUERYRESPONSE._serialized_start=13422
  _EXECUTEDATAQUERYRESPONSE._serialized_end=13494
  _EXECUTESCHEMEQUERYREQUEST._serialized_start=13496
  _EXECUTESCHEMEQUERYREQUEST._serialized_end=13620
  _EXECUTESCHEMEQUERYRESPONSE._serialized_start=13622
  _EXECUTESCHEMEQUERYRESPONSE._serialized_end=13696
  _TRANSACTIONMETA._serialized_start=13698
  _TRANSACTIONMETA._serialized_end=13727
  _QUERYMETA._serialized_start=13730
  _QUERYMETA._serialized_end=13889
  _QUERYMETA_PARAMETERSTYPESENTRY._serialized_start=13824
  _QUERYMETA_PARAMETERSTYPESENTRY._serialized_end=13889
  _EXECUTEQUERYRESULT._serialized_start=13892
  _EXECUTEQUERYRESULT._serialized_end=14085
  _EXPLAINDATAQUERYREQUEST._serialized_start=14088
  _EXPLAINDATAQUERYREQUEST._serialized_end=14244
  _EXPLAINDATAQUERYRESPONSE._serialized_start=14246
  _EXPLAINDATAQUERYRESPONSE._serialized_end=14318
  _EXPLAINQUERYRESULT._serialized_start=14320
  _EXPLAINQUERYRESULT._serialized_end=14411
  _PREPAREDATAQUERYREQUEST._serialized_start=14413
  _PREPAREDATAQUERYREQUEST._serialized_end=14535
  _PREPAREDATAQUERYRESPONSE._serialized_start=14537
  _PREPAREDATAQUERYRESPONSE._serialized_end=14609
  _PREPAREQUERYRESULT._serialized_start=14612
  _PREPAREQUERYRESULT._serialized_end=14795
  _PREPAREQUERYRESULT_PARAMETERSTYPESENTRY._serialized_start=13824
  _PREPAREQUERYRESULT_PARAMETERSTYPESENTRY._serialized_end=13889
  _KEEPALIVEREQUEST._serialized_start=14797
  _KEEPALIVEREQUEST._serialized_end=14894
  _KEEPALIVERESPONSE._serialized_start=14896
  _KEEPALIVERESPONSE._serialized_end=14961
  _KEEPALIVERESULT._serialized_start=14964
  _KEEPALIVERESULT._serialized_end=15147
  _KEEPALIVERESULT_SESSIONSTATUS._serialized_start=15049
  _KEEPALIVERESULT_SESSIONSTATUS._serialized_end=15147
  _BEGINTRANSACTIONREQUEST._serialized_start=15150
  _BEGINTRANSACTIONREQUEST._serialized_end=15307
  _BEGINTRANSACTIONRESPONSE._serialized_start=15309
  _BEGINTRANSACTIONRESPONSE._serialized_end=15381
  _BEGINTRANSACTIONRESULT._serialized_start=15383
  _BEGINTRANSACTIONRESULT._serialized_end=15452
  _COMMITTRANSACTIONREQUEST._serialized_start=15455
  _COMMITTRANSACTIONREQUEST._serialized_end=15636
  _COMMITTRANSACTIONRESPONSE._serialized_start=15638
  _COMMITTRANSACTIONRESPONSE._serialized_end=15711
  _COMMITTRANSACTIONRESULT._serialized_start=15713
  _COMMITTRANSACTIONRESULT._serialized_end=15787
  _ROLLBACKTRANSACTIONREQUEST._serialized_start=15789
  _ROLLBACKTRANSACTIONREQUEST._serialized_end=15911
  _ROLLBACKTRANSACTIONRESPONSE._serialized_start=15913
  _ROLLBACKTRANSACTIONRESPONSE._serialized_end=15988
  _STORAGEPOLICYDESCRIPTION._serialized_start=15991
  _STORAGEPOLICYDESCRIPTION._serialized_end=16143
  _STORAGEPOLICYDESCRIPTION_LABELSENTRY._serialized_start=16098
  _STORAGEPOLICYDESCRIPTION_LABELSENTRY._serialized_end=16143
  _COMPACTIONPOLICYDESCRIPTION._serialized_start=16146
  _COMPACTIONPOLICYDESCRIPTION._serialized_end=16304
  _COMPACTIONPOLICYDESCRIPTION_LABELSENTRY._serialized_start=16098
  _COMPACTIONPOLICYDESCRIPTION_LABELSENTRY._serialized_end=16143
  _PARTITIONINGPOLICYDESCRIPTION._serialized_start=16307
  _PARTITIONINGPOLICYDESCRIPTION._serialized_end=16469
  _PARTITIONINGPOLICYDESCRIPTION_LABELSENTRY._serialized_start=16098
  _PARTITIONINGPOLICYDESCRIPTION_LABELSENTRY._serialized_end=16143
  _EXECUTIONPOLICYDESCRIPTION._serialized_start=16472
  _EXECUTIONPOLICYDESCRIPTION._serialized_end=16628
  _EXECUTIONPOLICYDESCRIPTION_LABELSENTRY._serialized_start=16098
  _EXECUTIONPOLICYDESCRIPTION_LABELSENTRY._serialized_end=16143
  _REPLICATIONPOLICYDESCRIPTION._serialized_start=16631
  _REPLICATIONPOLICYDESCRIPTION._serialized_end=16791
  _REPLICATIONPOLICYDESCRIPTION_LABELSENTRY._serialized_start=16098
  _REPLICATIONPOLICYDESCRIPTION_LABELSENTRY._serialized_end=16143
  _CACHINGPOLICYDESCRIPTION._serialized_start=16794
  _CACHINGPOLICYDESCRIPTION._serialized_end=16946
  _CACHINGPOLICYDESCRIPTION_LABELSENTRY._serialized_start=16098
  _CACHINGPOLICYDESCRIPTION_LABELSENTRY._serialized_end=16143
  _TABLEPROFILEDESCRIPTION._serialized_start=16949
  _TABLEPROFILEDESCRIPTION._serialized_end=17523
  _TABLEPROFILEDESCRIPTION_LABELSENTRY._serialized_start=16098
  _TABLEPROFILEDESCRIPTION_LABELSENTRY._serialized_end=16143
  _DESCRIBETABLEOPTIONSREQUEST._serialized_start=17525
  _DESCRIBETABLEOPTIONSREQUEST._serialized_end=17613
  _DESCRIBETABLEOPTIONSRESPONSE._serialized_start=17615
  _DESCRIBETABLEOPTIONSRESPONSE._serialized_end=17691
  _DESCRIBETABLEOPTIONSRESULT._serialized_start=17694
  _DESCRIBETABLEOPTIONSRESULT._serialized_end=18231
  _KEYRANGE._serialized_start=18234
  _KEYRANGE._serialized_end=18426
  _READTABLEREQUEST._serialized_start=18429
  _READTABLEREQUEST._serialized_end=18741
  _READTABLERESPONSE._serialized_start=18744
  _READTABLERESPONSE._serialized_end=18932
  _READTABLERESULT._serialized_start=18934
  _READTABLERESULT._serialized_end=18987
  _READROWSREQUEST._serialized_start=18989
  _READROWSREQUEST._serialized_end=19088
  _READROWSRESPONSE._serialized_start=19091
  _READROWSRESPONSE._serialized_end=19229
  _BULKUPSERTREQUEST._serialized_start=19232
  _BULKUPSERTREQUEST._serialized_end=19501
  _BULKUPSERTRESPONSE._serialized_start=19503
  _BULKUPSERTRESPONSE._serialized_end=19569
  _BULKUPSERTRESULT._serialized_start=19571
  _BULKUPSERTRESULT._serialized_end=19589
  _EXECUTESCANQUERYREQUEST._serialized_start=19592
  _EXECUTESCANQUERYREQUEST._serialized_end=20027
  _EXECUTESCANQUERYREQUEST_PARAMETERSENTRY._serialized_start=13354
  _EXECUTESCANQUERYREQUEST_PARAMETERSENTRY._serialized_end=13420
  _EXECUTESCANQUERYREQUEST_MODE._serialized_start=19942
  _EXECUTESCANQUERYREQUEST_MODE._serialized_end=20003
  _EXECUTESCANQUERYPARTIALRESPONSE._serialized_start=20030
  _EXECUTESCANQUERYPARTIALRESPONSE._serialized_end=20205
  _EXECUTESCANQUERYPARTIALRESULT._serialized_start=20208
  _EXECUTESCANQUERYPARTIALRESULT._serialized_end=20380
# @@protoc_insertion_point(module_scope)



import asyncio


class AsyncResponseIterator(object):
    def __init__(self, it, wrapper):
        self.it = it.__aiter__()
        self.wrapper = wrapper

    def cancel(self):
        self.it.cancel()
        return self

    def __iter__(self):
        return self

    def __aiter__(self):
        return self

    async def _next(self):
        res = self.wrapper(await self.it.__anext__())

        if res is not None:
            return res
        return await self._next()

    async def next(self):
        return await self._next()

    async def __anext__(self):
        return await self._next()


async def get_first_message_with_timeout(stream: AsyncResponseIterator, timeout: int):
    async def get_first_response():
        return await stream.next()

    return await asyncio.wait_for(get_first_response(), timeout)



from draft.protos import ydb_object_storage_pb2 as _ydb_object_storage_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: draft/ydb_maintenance_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.draft.protos import ydb_maintenance_pb2 as draft_dot_protos_dot_ydb__maintenance__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='draft/ydb_maintenance_v1.proto',
  package='Ydb.Maintenance.V1',
  syntax='proto3',
  serialized_options=b'\n tech.ydb.proto.draft.maintenanceZ@github.com/ydb-platform/ydb-go-genproto/draft/Ydb_Maintenance_V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x64raft/ydb_maintenance_v1.proto\x12\x12Ydb.Maintenance.V1\x1a\"draft/protos/ydb_maintenance.proto2\x9c\x06\n\x12MaintenanceService\x12g\n\x10ListClusterNodes\x12(.Ydb.Maintenance.ListClusterNodesRequest\x1a).Ydb.Maintenance.ListClusterNodesResponse\x12p\n\x15\x43reateMaintenanceTask\x12-.Ydb.Maintenance.CreateMaintenanceTaskRequest\x1a(.Ydb.Maintenance.MaintenanceTaskResponse\x12r\n\x16RefreshMaintenanceTask\x12..Ydb.Maintenance.RefreshMaintenanceTaskRequest\x1a(.Ydb.Maintenance.MaintenanceTaskResponse\x12m\n\x12GetMaintenanceTask\x12*.Ydb.Maintenance.GetMaintenanceTaskRequest\x1a+.Ydb.Maintenance.GetMaintenanceTaskResponse\x12s\n\x14ListMaintenanceTasks\x12,.Ydb.Maintenance.ListMaintenanceTasksRequest\x1a-.Ydb.Maintenance.ListMaintenanceTasksResponse\x12r\n\x13\x44ropMaintenanceTask\x12+.Ydb.Maintenance.DropMaintenanceTaskRequest\x1a..Ydb.Maintenance.ManageMaintenanceTaskResponse\x12_\n\x0e\x43ompleteAction\x12&.Ydb.Maintenance.CompleteActionRequest\x1a%.Ydb.Maintenance.ManageActionResponseBd\n tech.ydb.proto.draft.maintenanceZ@github.com/ydb-platform/ydb-go-genproto/draft/Ydb_Maintenance_V1b\x06proto3'
  ,
  dependencies=[draft_dot_protos_dot_ydb__maintenance__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_MAINTENANCESERVICE = _descriptor.ServiceDescriptor(
  name='MaintenanceService',
  full_name='Ydb.Maintenance.V1.MaintenanceService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=91,
  serialized_end=887,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListClusterNodes',
    full_name='Ydb.Maintenance.V1.MaintenanceService.ListClusterNodes',
    index=0,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__maintenance__pb2._LISTCLUSTERNODESREQUEST,
    output_type=draft_dot_protos_dot_ydb__maintenance__pb2._LISTCLUSTERNODESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateMaintenanceTask',
    full_name='Ydb.Maintenance.V1.MaintenanceService.CreateMaintenanceTask',
    index=1,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__maintenance__pb2._CREATEMAINTENANCETASKREQUEST,
    output_type=draft_dot_protos_dot_ydb__maintenance__pb2._MAINTENANCETASKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RefreshMaintenanceTask',
    full_name='Ydb.Maintenance.V1.MaintenanceService.RefreshMaintenanceTask',
    index=2,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__maintenance__pb2._REFRESHMAINTENANCETASKREQUEST,
    output_type=draft_dot_protos_dot_ydb__maintenance__pb2._MAINTENANCETASKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMaintenanceTask',
    full_name='Ydb.Maintenance.V1.MaintenanceService.GetMaintenanceTask',
    index=3,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__maintenance__pb2._GETMAINTENANCETASKREQUEST,
    output_type=draft_dot_protos_dot_ydb__maintenance__pb2._GETMAINTENANCETASKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMaintenanceTasks',
    full_name='Ydb.Maintenance.V1.MaintenanceService.ListMaintenanceTasks',
    index=4,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__maintenance__pb2._LISTMAINTENANCETASKSREQUEST,
    output_type=draft_dot_protos_dot_ydb__maintenance__pb2._LISTMAINTENANCETASKSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DropMaintenanceTask',
    full_name='Ydb.Maintenance.V1.MaintenanceService.DropMaintenanceTask',
    index=5,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__maintenance__pb2._DROPMAINTENANCETASKREQUEST,
    output_type=draft_dot_protos_dot_ydb__maintenance__pb2._MANAGEMAINTENANCETASKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CompleteAction',
    full_name='Ydb.Maintenance.V1.MaintenanceService.CompleteAction',
    index=6,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__maintenance__pb2._COMPLETEACTIONREQUEST,
    output_type=draft_dot_protos_dot_ydb__maintenance__pb2._MANAGEACTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MAINTENANCESERVICE)

DESCRIPTOR.services_by_name['MaintenanceService'] = _MAINTENANCESERVICE

# @@protoc_insertion_point(module_scope)



import pytest
import ydb
from unittest.mock import patch, MagicMock


USERNAME = "root"
PASSWORD = "1234"


def check_driver_works(driver):
    driver.wait(timeout=15)
    pool = ydb.QuerySessionPool(driver)
    result = pool.execute_with_retries("SELECT 1 as cnt")
    assert result[0].rows[0].cnt == 1


def test_static_credentials_default(endpoint, database):
    driver_config = ydb.DriverConfig(
        endpoint,
        database,
    )
    credentials = ydb.StaticCredentials(driver_config, USERNAME, PASSWORD)

    with ydb.Driver(driver_config=driver_config, credentials=credentials) as driver:
        check_driver_works(driver)


def test_static_credentials_classmethod(endpoint, database):
    driver_config = ydb.DriverConfig(
        endpoint,
        database,
        credentials=ydb.StaticCredentials.from_user_password(USERNAME, PASSWORD),
    )

    with ydb.Driver(driver_config=driver_config) as driver:
        check_driver_works(driver)


def test_static_credentials_wrong_creds(endpoint, database):
    driver_config = ydb.DriverConfig(
        endpoint,
        database,
        credentials=ydb.StaticCredentials.from_user_password(USERNAME, PASSWORD * 2),
    )

    with pytest.raises(ydb.ConnectionFailure):
        with ydb.Driver(driver_config=driver_config) as driver:
            driver.wait(5, fail_fast=True)


def test_token_lazy_refresh():
    credentials = ydb.StaticCredentials.from_user_password(USERNAME, PASSWORD)

    credentials._tp.submit = MagicMock()

    mock_response = {"access_token": "token_v1", "expires_in": 3600}
    credentials._make_token_request = MagicMock(return_value=mock_response)

    with patch("time.time") as mock_time:
        mock_time.return_value = 1000

        token1 = credentials.token
        assert token1 == "token_v1"
        assert credentials._make_token_request.call_count == 1

        token2 = credentials.token
        assert token2 == "token_v1"
        assert credentials._make_token_request.call_count == 1

        mock_time.return_value = 1000 + 3600 - 30 + 1
        credentials._make_token_request.return_value = {"access_token": "token_v2", "expires_in": 3600}

        token3 = credentials.token
        assert token3 == "token_v2"
        assert credentials._make_token_request.call_count == 2


def test_token_double_check_locking():
    credentials = ydb.StaticCredentials.from_user_password(USERNAME, PASSWORD)
    credentials._tp.submit = MagicMock()

    call_count = 0

    def mock_make_request():
        nonlocal call_count
        call_count += 1
        return {"access_token": f"token_v{call_count}", "expires_in": 3600}

    credentials._make_token_request = mock_make_request

    with patch("time.time") as mock_time:
        mock_time.return_value = 1000

        import threading

        results = []

        def get_token():
            results.append(credentials.token)

        threads = [threading.Thread(target=get_token) for _ in range(10)]
        for t in threads:
            t.start()
        for t in threads:
            t.join()

        assert len(set(results)) == 1
        assert call_count == 1


def test_token_expiration_calculation():
    credentials = ydb.StaticCredentials.from_user_password(USERNAME, PASSWORD)

    credentials._tp.submit = MagicMock()

    with patch("time.time") as mock_time:
        mock_time.return_value = 1000

        credentials._make_token_request = MagicMock(return_value={"access_token": "token", "expires_in": 3600})

        credentials.token

        expected_expires = 1000 + 3600 - 30
        assert credentials._expires_in == expected_expires


def test_token_refresh_error_handling():
    credentials = ydb.StaticCredentials.from_user_password(USERNAME, PASSWORD)
    credentials._tp.submit = MagicMock()
    credentials._make_token_request = MagicMock(side_effect=Exception("Network error"))

    with patch("time.time") as mock_time:
        mock_time.return_value = 1000 + 3600

        with pytest.raises(ydb.ConnectionError) as exc_info:
            credentials.token

        assert "Network error" in str(exc_info.value)
        assert credentials.last_error == "Network error"


def test_hybrid_background_and_sync_refresh():
    credentials = ydb.StaticCredentials.from_user_password(USERNAME, PASSWORD)

    call_count = 0
    background_calls = []

    def mock_make_request():
        nonlocal call_count
        call_count += 1
        return {"access_token": f"token_v{call_count}", "expires_in": 3600}

    def mock_submit(callback):
        background_calls.append(callback)

    credentials._make_token_request = mock_make_request
    credentials._tp.submit = mock_submit

    with patch("time.time") as mock_time:
        mock_time.return_value = 1000

        token1 = credentials.token
        assert token1 == "token_v1"
        assert call_count == 1
        assert len(background_calls) == 0

        mock_time.return_value = 1000 + min(1800, 3600 / 10) + 1
        token2 = credentials.token
        assert token2 == "token_v1"
        assert call_count == 1
        assert len(background_calls) == 1

        mock_time.return_value = 1000 + 3600 - 30 + 1
        token3 = credentials.token
        assert token3 == "token_v2"
        assert call_count == 2



from protos import ydb_operation_pb2 as _ydb_operation_pb2
from protos import ydb_status_codes_pb2 as _ydb_status_codes_pb2
from protos import ydb_issue_message_pb2 as _ydb_issue_message_pb2
from protos import ydb_scheme_pb2 as _ydb_scheme_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

CONSISTENCY_MODE_RELAXED: ConsistencyMode
CONSISTENCY_MODE_STRICT: ConsistencyMode
CONSISTENCY_MODE_UNSET: ConsistencyMode
DESCRIPTOR: _descriptor.FileDescriptor
RATE_LIMITER_COUNTERS_MODE_AGGREGATED: RateLimiterCountersMode
RATE_LIMITER_COUNTERS_MODE_DETAILED: RateLimiterCountersMode
RATE_LIMITER_COUNTERS_MODE_UNSET: RateLimiterCountersMode

class AlterNodeRequest(_message.Message):
    __slots__ = ["config", "operation_params", "path"]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    OPERATION_PARAMS_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    config: Config
    operation_params: _ydb_operation_pb2.OperationParams
    path: str
    def __init__(self, path: _Optional[str] = ..., config: _Optional[_Union[Config, _Mapping]] = ..., operation_params: _Optional[_Union[_ydb_operation_pb2.OperationParams, _Mapping]] = ...) -> None: ...

class AlterNodeResponse(_message.Message):
    __slots__ = ["operation"]
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    operation: _ydb_operation_pb2.Operation
    def __init__(self, operation: _Optional[_Union[_ydb_operation_pb2.Operation, _Mapping]] = ...) -> None: ...

class Config(_message.Message):
    __slots__ = ["attach_consistency_mode", "path", "rate_limiter_counters_mode", "read_consistency_mode", "self_check_period_millis", "session_grace_period_millis"]
    ATTACH_CONSISTENCY_MODE_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    RATE_LIMITER_COUNTERS_MODE_FIELD_NUMBER: _ClassVar[int]
    READ_CONSISTENCY_MODE_FIELD_NUMBER: _ClassVar[int]
    SELF_CHECK_PERIOD_MILLIS_FIELD_NUMBER: _ClassVar[int]
    SESSION_GRACE_PERIOD_MILLIS_FIELD_NUMBER: _ClassVar[int]
    attach_consistency_mode: ConsistencyMode
    path: str
    rate_limiter_counters_mode: RateLimiterCountersMode
    read_consistency_mode: ConsistencyMode
    self_check_period_millis: int
    session_grace_period_millis: int
    def __init__(self, path: _Optional[str] = ..., self_check_period_millis: _Optional[int] = ..., session_grace_period_millis: _Optional[int] = ..., read_consistency_mode: _Optional[_Union[ConsistencyMode, str]] = ..., attach_consistency_mode: _Optional[_Union[ConsistencyMode, str]] = ..., rate_limiter_counters_mode: _Optional[_Union[RateLimiterCountersMode, str]] = ...) -> None: ...

class CreateNodeRequest(_message.Message):
    __slots__ = ["config", "operation_params", "path"]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    OPERATION_PARAMS_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    config: Config
    operation_params: _ydb_operation_pb2.OperationParams
    path: str
    def __init__(self, path: _Optional[str] = ..., config: _Optional[_Union[Config, _Mapping]] = ..., operation_params: _Optional[_Union[_ydb_operation_pb2.OperationParams, _Mapping]] = ...) -> None: ...

class CreateNodeResponse(_message.Message):
    __slots__ = ["operation"]
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    operation: _ydb_operation_pb2.Operation
    def __init__(self, operation: _Optional[_Union[_ydb_operation_pb2.Operation, _Mapping]] = ...) -> None: ...

class DescribeNodeRequest(_message.Message):
    __slots__ = ["operation_params", "path"]
    OPERATION_PARAMS_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    operation_params: _ydb_operation_pb2.OperationParams
    path: str
    def __init__(self, path: _Optional[str] = ..., operation_params: _Optional[_Union[_ydb_operation_pb2.OperationParams, _Mapping]] = ...) -> None: ...

class DescribeNodeResponse(_message.Message):
    __slots__ = ["operation"]
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    operation: _ydb_operation_pb2.Operation
    def __init__(self, operation: _Optional[_Union[_ydb_operation_pb2.Operation, _Mapping]] = ...) -> None: ...

class DescribeNodeResult(_message.Message):
    __slots__ = ["config", "self"]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    SELF_FIELD_NUMBER: _ClassVar[int]
    config: Config
    self: _ydb_scheme_pb2.Entry
    def __init__(self, self_: _Optional[_Union[_ydb_scheme_pb2.Entry, _Mapping]] = ..., config: _Optional[_Union[Config, _Mapping]] = ...) -> None: ...

class DropNodeRequest(_message.Message):
    __slots__ = ["operation_params", "path"]
    OPERATION_PARAMS_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    operation_params: _ydb_operation_pb2.OperationParams
    path: str
    def __init__(self, path: _Optional[str] = ..., operation_params: _Optional[_Union[_ydb_operation_pb2.OperationParams, _Mapping]] = ...) -> None: ...

class DropNodeResponse(_message.Message):
    __slots__ = ["operation"]
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    operation: _ydb_operation_pb2.Operation
    def __init__(self, operation: _Optional[_Union[_ydb_operation_pb2.Operation, _Mapping]] = ...) -> None: ...

class SemaphoreDescription(_message.Message):
    __slots__ = ["count", "data", "ephemeral", "limit", "name", "owners", "waiters"]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    EPHEMERAL_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    WAITERS_FIELD_NUMBER: _ClassVar[int]
    count: int
    data: bytes
    ephemeral: bool
    limit: int
    name: str
    owners: _containers.RepeatedCompositeFieldContainer[SemaphoreSession]
    waiters: _containers.RepeatedCompositeFieldContainer[SemaphoreSession]
    def __init__(self, name: _Optional[str] = ..., data: _Optional[bytes] = ..., count: _Optional[int] = ..., limit: _Optional[int] = ..., ephemeral: bool = ..., owners: _Optional[_Iterable[_Union[SemaphoreSession, _Mapping]]] = ..., waiters: _Optional[_Iterable[_Union[SemaphoreSession, _Mapping]]] = ...) -> None: ...

class SemaphoreSession(_message.Message):
    __slots__ = ["count", "data", "order_id", "session_id", "timeout_millis"]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_MILLIS_FIELD_NUMBER: _ClassVar[int]
    count: int
    data: bytes
    order_id: int
    session_id: int
    timeout_millis: int
    def __init__(self, order_id: _Optional[int] = ..., session_id: _Optional[int] = ..., timeout_millis: _Optional[int] = ..., count: _Optional[int] = ..., data: _Optional[bytes] = ...) -> None: ...

class SessionDescription(_message.Message):
    __slots__ = ["attached", "description", "session_id", "timeout_millis"]
    ATTACHED_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_MILLIS_FIELD_NUMBER: _ClassVar[int]
    attached: bool
    description: str
    session_id: int
    timeout_millis: int
    def __init__(self, session_id: _Optional[int] = ..., timeout_millis: _Optional[int] = ..., description: _Optional[str] = ..., attached: bool = ...) -> None: ...

class SessionRequest(_message.Message):
    __slots__ = ["acquire_semaphore", "create_semaphore", "delete_semaphore", "describe_semaphore", "ping", "pong", "release_semaphore", "session_start", "session_stop", "unsupported_13", "unsupported_14", "unsupported_15", "unsupported_5", "unsupported_6", "update_semaphore"]
    class AcquireSemaphore(_message.Message):
        __slots__ = ["count", "data", "ephemeral", "name", "req_id", "timeout_millis"]
        COUNT_FIELD_NUMBER: _ClassVar[int]
        DATA_FIELD_NUMBER: _ClassVar[int]
        EPHEMERAL_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        REQ_ID_FIELD_NUMBER: _ClassVar[int]
        TIMEOUT_MILLIS_FIELD_NUMBER: _ClassVar[int]
        count: int
        data: bytes
        ephemeral: bool
        name: str
        req_id: int
        timeout_millis: int
        def __init__(self, req_id: _Optional[int] = ..., name: _Optional[str] = ..., timeout_millis: _Optional[int] = ..., count: _Optional[int] = ..., data: _Optional[bytes] = ..., ephemeral: bool = ...) -> None: ...
    class CreateSemaphore(_message.Message):
        __slots__ = ["data", "limit", "name", "req_id"]
        DATA_FIELD_NUMBER: _ClassVar[int]
        LIMIT_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        REQ_ID_FIELD_NUMBER: _ClassVar[int]
        data: bytes
        limit: int
        name: str
        req_id: int
        def __init__(self, req_id: _Optional[int] = ..., name: _Optional[str] = ..., limit: _Optional[int] = ..., data: _Optional[bytes] = ...) -> None: ...
    class DeleteSemaphore(_message.Message):
        __slots__ = ["force", "name", "req_id"]
        FORCE_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        REQ_ID_FIELD_NUMBER: _ClassVar[int]
        force: bool
        name: str
        req_id: int
        def __init__(self, req_id: _Optional[int] = ..., name: _Optional[str] = ..., force: bool = ...) -> None: ...
    class DescribeSemaphore(_message.Message):
        __slots__ = ["include_owners", "include_waiters", "name", "req_id", "watch_data", "watch_owners"]
        INCLUDE_OWNERS_FIELD_NUMBER: _ClassVar[int]
        INCLUDE_WAITERS_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        REQ_ID_FIELD_NUMBER: _ClassVar[int]
        WATCH_DATA_FIELD_NUMBER: _ClassVar[int]
        WATCH_OWNERS_FIELD_NUMBER: _ClassVar[int]
        include_owners: bool
        include_waiters: bool
        name: str
        req_id: int
        watch_data: bool
        watch_owners: bool
        def __init__(self, req_id: _Optional[int] = ..., name: _Optional[str] = ..., include_owners: bool = ..., include_waiters: bool = ..., watch_data: bool = ..., watch_owners: bool = ...) -> None: ...
    class PingPong(_message.Message):
        __slots__ = ["opaque"]
        OPAQUE_FIELD_NUMBER: _ClassVar[int]
        opaque: int
        def __init__(self, opaque: _Optional[int] = ...) -> None: ...
    class ReleaseSemaphore(_message.Message):
        __slots__ = ["name", "req_id"]
        NAME_FIELD_NUMBER: _ClassVar[int]
        REQ_ID_FIELD_NUMBER: _ClassVar[int]
        name: str
        req_id: int
        def __init__(self, req_id: _Optional[int] = ..., name: _Optional[str] = ...) -> None: ...
    class SessionStart(_message.Message):
        __slots__ = ["description", "path", "protection_key", "seq_no", "session_id", "timeout_millis"]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        PROTECTION_KEY_FIELD_NUMBER: _ClassVar[int]
        SEQ_NO_FIELD_NUMBER: _ClassVar[int]
        SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        TIMEOUT_MILLIS_FIELD_NUMBER: _ClassVar[int]
        description: str
        path: str
        protection_key: bytes
        seq_no: int
        session_id: int
        timeout_millis: int
        def __init__(self, path: _Optional[str] = ..., session_id: _Optional[int] = ..., timeout_millis: _Optional[int] = ..., description: _Optional[str] = ..., seq_no: _Optional[int] = ..., protection_key: _Optional[bytes] = ...) -> None: ...
    class SessionStop(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    class UpdateSemaphore(_message.Message):
        __slots__ = ["data", "name", "req_id"]
        DATA_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        REQ_ID_FIELD_NUMBER: _ClassVar[int]
        data: bytes
        name: str
        req_id: int
        def __init__(self, req_id: _Optional[int] = ..., name: _Optional[str] = ..., data: _Optional[bytes] = ...) -> None: ...
    ACQUIRE_SEMAPHORE_FIELD_NUMBER: _ClassVar[int]
    CREATE_SEMAPHORE_FIELD_NUMBER: _ClassVar[int]
    DELETE_SEMAPHORE_FIELD_NUMBER: _ClassVar[int]
    DESCRIBE_SEMAPHORE_FIELD_NUMBER: _ClassVar[int]
    PING_FIELD_NUMBER: _ClassVar[int]
    PONG_FIELD_NUMBER: _ClassVar[int]
    RELEASE_SEMAPHORE_FIELD_NUMBER: _ClassVar[int]
    SESSION_START_FIELD_NUMBER: _ClassVar[int]
    SESSION_STOP_FIELD_NUMBER: _ClassVar[int]
    UNSUPPORTED_13_FIELD_NUMBER: _ClassVar[int]
    UNSUPPORTED_14_FIELD_NUMBER: _ClassVar[int]
    UNSUPPORTED_15_FIELD_NUMBER: _ClassVar[int]
    UNSUPPORTED_5_FIELD_NUMBER: _ClassVar[int]
    UNSUPPORTED_6_FIELD_NUMBER: _ClassVar[int]
    UPDATE_SEMAPHORE_FIELD_NUMBER: _ClassVar[int]
    acquire_semaphore: SessionRequest.AcquireSemaphore
    create_semaphore: SessionRequest.CreateSemaphore
    delete_semaphore: SessionRequest.DeleteSemaphore
    describe_semaphore: SessionRequest.DescribeSemaphore
    ping: SessionRequest.PingPong
    pong: SessionRequest.PingPong
    release_semaphore: SessionRequest.ReleaseSemaphore
    session_start: SessionRequest.SessionStart
    session_stop: SessionRequest.SessionStop
    unsupported_13: Unsupported
    unsupported_14: Unsupported
    unsupported_15: Unsupported
    unsupported_5: Unsupported
    unsupported_6: Unsupported
    update_semaphore: SessionRequest.UpdateSemaphore
    def __init__(self, ping: _Optional[_Union[SessionRequest.PingPong, _Mapping]] = ..., pong: _Optional[_Union[SessionRequest.PingPong, _Mapping]] = ..., session_start: _Optional[_Union[SessionRequest.SessionStart, _Mapping]] = ..., session_stop: _Optional[_Union[SessionRequest.SessionStop, _Mapping]] = ..., unsupported_5: _Optional[_Union[Unsupported, _Mapping]] = ..., unsupported_6: _Optional[_Union[Unsupported, _Mapping]] = ..., acquire_semaphore: _Optional[_Union[SessionRequest.AcquireSemaphore, _Mapping]] = ..., release_semaphore: _Optional[_Union[SessionRequest.ReleaseSemaphore, _Mapping]] = ..., describe_semaphore: _Optional[_Union[SessionRequest.DescribeSemaphore, _Mapping]] = ..., create_semaphore: _Optional[_Union[SessionRequest.CreateSemaphore, _Mapping]] = ..., update_semaphore: _Optional[_Union[SessionRequest.UpdateSemaphore, _Mapping]] = ..., delete_semaphore: _Optional[_Union[SessionRequest.DeleteSemaphore, _Mapping]] = ..., unsupported_13: _Optional[_Union[Unsupported, _Mapping]] = ..., unsupported_14: _Optional[_Union[Unsupported, _Mapping]] = ..., unsupported_15: _Optional[_Union[Unsupported, _Mapping]] = ...) -> None: ...

class SessionResponse(_message.Message):
    __slots__ = ["acquire_semaphore_pending", "acquire_semaphore_result", "create_semaphore_result", "delete_semaphore_result", "describe_semaphore_changed", "describe_semaphore_result", "failure", "ping", "pong", "release_semaphore_result", "session_started", "session_stopped", "unsupported_16", "unsupported_17", "unsupported_18", "unsupported_6", "unsupported_7", "update_semaphore_result"]
    class AcquireSemaphorePending(_message.Message):
        __slots__ = ["req_id"]
        REQ_ID_FIELD_NUMBER: _ClassVar[int]
        req_id: int
        def __init__(self, req_id: _Optional[int] = ...) -> None: ...
    class AcquireSemaphoreResult(_message.Message):
        __slots__ = ["acquired", "issues", "req_id", "status"]
        ACQUIRED_FIELD_NUMBER: _ClassVar[int]
        ISSUES_FIELD_NUMBER: _ClassVar[int]
        REQ_ID_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        acquired: bool
        issues: _containers.RepeatedCompositeFieldContainer[_ydb_issue_message_pb2.IssueMessage]
        req_id: int
        status: _ydb_status_codes_pb2.StatusIds.StatusCode
        def __init__(self, req_id: _Optional[int] = ..., status: _Optional[_Union[_ydb_status_codes_pb2.StatusIds.StatusCode, str]] = ..., issues: _Optional[_Iterable[_Union[_ydb_issue_message_pb2.IssueMessage, _Mapping]]] = ..., acquired: bool = ...) -> None: ...
    class CreateSemaphoreResult(_message.Message):
        __slots__ = ["issues", "req_id", "status"]
        ISSUES_FIELD_NUMBER: _ClassVar[int]
        REQ_ID_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        issues: _containers.RepeatedCompositeFieldContainer[_ydb_issue_message_pb2.IssueMessage]
        req_id: int
        status: _ydb_status_codes_pb2.StatusIds.StatusCode
        def __init__(self, req_id: _Optional[int] = ..., status: _Optional[_Union[_ydb_status_codes_pb2.StatusIds.StatusCode, str]] = ..., issues: _Optional[_Iterable[_Union[_ydb_issue_message_pb2.IssueMessage, _Mapping]]] = ...) -> None: ...
    class DeleteSemaphoreResult(_message.Message):
        __slots__ = ["issues", "req_id", "status"]
        ISSUES_FIELD_NUMBER: _ClassVar[int]
        REQ_ID_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        issues: _containers.RepeatedCompositeFieldContainer[_ydb_issue_message_pb2.IssueMessage]
        req_id: int
        status: _ydb_status_codes_pb2.StatusIds.StatusCode
        def __init__(self, req_id: _Optional[int] = ..., status: _Optional[_Union[_ydb_status_codes_pb2.StatusIds.StatusCode, str]] = ..., issues: _Optional[_Iterable[_Union[_ydb_issue_message_pb2.IssueMessage, _Mapping]]] = ...) -> None: ...
    class DescribeSemaphoreChanged(_message.Message):
        __slots__ = ["data_changed", "owners_changed", "req_id"]
        DATA_CHANGED_FIELD_NUMBER: _ClassVar[int]
        OWNERS_CHANGED_FIELD_NUMBER: _ClassVar[int]
        REQ_ID_FIELD_NUMBER: _ClassVar[int]
        data_changed: bool
        owners_changed: bool
        req_id: int
        def __init__(self, req_id: _Optional[int] = ..., data_changed: bool = ..., owners_changed: bool = ...) -> None: ...
    class DescribeSemaphoreResult(_message.Message):
        __slots__ = ["issues", "req_id", "semaphore_description", "status", "watch_added"]
        ISSUES_FIELD_NUMBER: _ClassVar[int]
        REQ_ID_FIELD_NUMBER: _ClassVar[int]
        SEMAPHORE_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        WATCH_ADDED_FIELD_NUMBER: _ClassVar[int]
        issues: _containers.RepeatedCompositeFieldContainer[_ydb_issue_message_pb2.IssueMessage]
        req_id: int
        semaphore_description: SemaphoreDescription
        status: _ydb_status_codes_pb2.StatusIds.StatusCode
        watch_added: bool
        def __init__(self, req_id: _Optional[int] = ..., status: _Optional[_Union[_ydb_status_codes_pb2.StatusIds.StatusCode, str]] = ..., issues: _Optional[_Iterable[_Union[_ydb_issue_message_pb2.IssueMessage, _Mapping]]] = ..., semaphore_description: _Optional[_Union[SemaphoreDescription, _Mapping]] = ..., watch_added: bool = ...) -> None: ...
    class Failure(_message.Message):
        __slots__ = ["issues", "status"]
        ISSUES_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        issues: _containers.RepeatedCompositeFieldContainer[_ydb_issue_message_pb2.IssueMessage]
        status: _ydb_status_codes_pb2.StatusIds.StatusCode
        def __init__(self, status: _Optional[_Union[_ydb_status_codes_pb2.StatusIds.StatusCode, str]] = ..., issues: _Optional[_Iterable[_Union[_ydb_issue_message_pb2.IssueMessage, _Mapping]]] = ...) -> None: ...
    class PingPong(_message.Message):
        __slots__ = ["opaque"]
        OPAQUE_FIELD_NUMBER: _ClassVar[int]
        opaque: int
        def __init__(self, opaque: _Optional[int] = ...) -> None: ...
    class ReleaseSemaphoreResult(_message.Message):
        __slots__ = ["issues", "released", "req_id", "status"]
        ISSUES_FIELD_NUMBER: _ClassVar[int]
        RELEASED_FIELD_NUMBER: _ClassVar[int]
        REQ_ID_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        issues: _containers.RepeatedCompositeFieldContainer[_ydb_issue_message_pb2.IssueMessage]
        released: bool
        req_id: int
        status: _ydb_status_codes_pb2.StatusIds.StatusCode
        def __init__(self, req_id: _Optional[int] = ..., status: _Optional[_Union[_ydb_status_codes_pb2.StatusIds.StatusCode, str]] = ..., issues: _Optional[_Iterable[_Union[_ydb_issue_message_pb2.IssueMessage, _Mapping]]] = ..., released: bool = ...) -> None: ...
    class SessionStarted(_message.Message):
        __slots__ = ["session_id", "timeout_millis"]
        SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        TIMEOUT_MILLIS_FIELD_NUMBER: _ClassVar[int]
        session_id: int
        timeout_millis: int
        def __init__(self, session_id: _Optional[int] = ..., timeout_millis: _Optional[int] = ...) -> None: ...
    class SessionStopped(_message.Message):
        __slots__ = ["session_id"]
        SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        session_id: int
        def __init__(self, session_id: _Optional[int] = ...) -> None: ...
    class UpdateSemaphoreResult(_message.Message):
        __slots__ = ["issues", "req_id", "status"]
        ISSUES_FIELD_NUMBER: _ClassVar[int]
        REQ_ID_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        issues: _containers.RepeatedCompositeFieldContainer[_ydb_issue_message_pb2.IssueMessage]
        req_id: int
        status: _ydb_status_codes_pb2.StatusIds.StatusCode
        def __init__(self, req_id: _Optional[int] = ..., status: _Optional[_Union[_ydb_status_codes_pb2.StatusIds.StatusCode, str]] = ..., issues: _Optional[_Iterable[_Union[_ydb_issue_message_pb2.IssueMessage, _Mapping]]] = ...) -> None: ...
    ACQUIRE_SEMAPHORE_PENDING_FIELD_NUMBER: _ClassVar[int]
    ACQUIRE_SEMAPHORE_RESULT_FIELD_NUMBER: _ClassVar[int]
    CREATE_SEMAPHORE_RESULT_FIELD_NUMBER: _ClassVar[int]
    DELETE_SEMAPHORE_RESULT_FIELD_NUMBER: _ClassVar[int]
    DESCRIBE_SEMAPHORE_CHANGED_FIELD_NUMBER: _ClassVar[int]
    DESCRIBE_SEMAPHORE_RESULT_FIELD_NUMBER: _ClassVar[int]
    FAILURE_FIELD_NUMBER: _ClassVar[int]
    PING_FIELD_NUMBER: _ClassVar[int]
    PONG_FIELD_NUMBER: _ClassVar[int]
    RELEASE_SEMAPHORE_RESULT_FIELD_NUMBER: _ClassVar[int]
    SESSION_STARTED_FIELD_NUMBER: _ClassVar[int]
    SESSION_STOPPED_FIELD_NUMBER: _ClassVar[int]
    UNSUPPORTED_16_FIELD_NUMBER: _ClassVar[int]
    UNSUPPORTED_17_FIELD_NUMBER: _ClassVar[int]
    UNSUPPORTED_18_FIELD_NUMBER: _ClassVar[int]
    UNSUPPORTED_6_FIELD_NUMBER: _ClassVar[int]
    UNSUPPORTED_7_FIELD_NUMBER: _ClassVar[int]
    UPDATE_SEMAPHORE_RESULT_FIELD_NUMBER: _ClassVar[int]
    acquire_semaphore_pending: SessionResponse.AcquireSemaphorePending
    acquire_semaphore_result: SessionResponse.AcquireSemaphoreResult
    create_semaphore_result: SessionResponse.CreateSemaphoreResult
    delete_semaphore_result: SessionResponse.DeleteSemaphoreResult
    describe_semaphore_changed: SessionResponse.DescribeSemaphoreChanged
    describe_semaphore_result: SessionResponse.DescribeSemaphoreResult
    failure: SessionResponse.Failure
    ping: SessionResponse.PingPong
    pong: SessionResponse.PingPong
    release_semaphore_result: SessionResponse.ReleaseSemaphoreResult
    session_started: SessionResponse.SessionStarted
    session_stopped: SessionResponse.SessionStopped
    unsupported_16: Unsupported
    unsupported_17: Unsupported
    unsupported_18: Unsupported
    unsupported_6: Unsupported
    unsupported_7: Unsupported
    update_semaphore_result: SessionResponse.UpdateSemaphoreResult
    def __init__(self, ping: _Optional[_Union[SessionResponse.PingPong, _Mapping]] = ..., pong: _Optional[_Union[SessionResponse.PingPong, _Mapping]] = ..., failure: _Optional[_Union[SessionResponse.Failure, _Mapping]] = ..., session_started: _Optional[_Union[SessionResponse.SessionStarted, _Mapping]] = ..., session_stopped: _Optional[_Union[SessionResponse.SessionStopped, _Mapping]] = ..., unsupported_6: _Optional[_Union[Unsupported, _Mapping]] = ..., unsupported_7: _Optional[_Union[Unsupported, _Mapping]] = ..., acquire_semaphore_pending: _Optional[_Union[SessionResponse.AcquireSemaphorePending, _Mapping]] = ..., acquire_semaphore_result: _Optional[_Union[SessionResponse.AcquireSemaphoreResult, _Mapping]] = ..., release_semaphore_result: _Optional[_Union[SessionResponse.ReleaseSemaphoreResult, _Mapping]] = ..., describe_semaphore_result: _Optional[_Union[SessionResponse.DescribeSemaphoreResult, _Mapping]] = ..., describe_semaphore_changed: _Optional[_Union[SessionResponse.DescribeSemaphoreChanged, _Mapping]] = ..., create_semaphore_result: _Optional[_Union[SessionResponse.CreateSemaphoreResult, _Mapping]] = ..., update_semaphore_result: _Optional[_Union[SessionResponse.UpdateSemaphoreResult, _Mapping]] = ..., delete_semaphore_result: _Optional[_Union[SessionResponse.DeleteSemaphoreResult, _Mapping]] = ..., unsupported_16: _Optional[_Union[Unsupported, _Mapping]] = ..., unsupported_17: _Optional[_Union[Unsupported, _Mapping]] = ..., unsupported_18: _Optional[_Union[Unsupported, _Mapping]] = ...) -> None: ...

class Unsupported(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ConsistencyMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class RateLimiterCountersMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



import pytest
import ydb

from datetime import date, datetime, timedelta, timezone
from decimal import Decimal
from uuid import uuid4


@pytest.mark.parametrize(
    "value,ydb_type",
    [
        (True, "Bool"),
        (-125, "Int8"),
        (None, "Int8?"),
        (-32766, "Int16"),
        (-1123, "Int32"),
        (-2157583648, "Int64"),
        (255, "UInt8"),
        (65534, "UInt16"),
        (5555, "UInt32"),
        (2157583649, "UInt64"),
        (3.1415, "Double"),
        (".31415926535e1", "DyNumber"),
        (Decimal("3.1415926535"), "Decimal(28, 10)"),
        (b"Hello, YDB!", "String"),
        ("Hello, 🐍!", "Utf8"),
        ('{"foo": "bar"}', "Json"),
        (b'{"foo"="bar"}', "Yson"),
        ('{"foo":"bar"}', "JsonDocument"),
        (uuid4(), "Uuid"),
        ([1, 2, 3], "List<Int8>"),
        ({1: None, 2: None, 3: None}, "Set<Int8>"),
        ([b"a", b"b", b"c"], "List<String>"),
        ({"a": 1001, "b": 1002}, "Dict<Utf8, Int32>"),
        (("a", 1001), "Tuple<Utf8, Int32>"),
        ({"foo": True, "bar": None}, "Struct<foo:Bool?, bar:Int32?>"),
        (100, "Date"),
        (100, "Datetime"),
        (-100, "Interval"),
        (100, "Timestamp"),
        (1511789040123456, "Timestamp"),
    ],
)
@pytest.mark.asyncio
async def test_types(driver, database, value, ydb_type):
    session = await driver.table_client.session().create()
    prepared = await session.prepare(f"DECLARE $param as {ydb_type}; SELECT $param as value")
    result = await session.transaction().execute(prepared, {"$param": value}, commit_tx=True)
    assert result[0].rows[0].value == value


test_td = timedelta(microseconds=-100)
test_now = datetime.utcnow()
test_today = test_now.date()
test_dt_today = datetime.today()
tz4h = timezone(timedelta(hours=4))


@pytest.mark.parametrize(
    "value,ydb_type,result_value",
    [
        # FIXME: TypeError: 'datetime.datetime' object cannot be interpreted as an integer
        # (test_dt_today, "Datetime", test_dt_today),
        (test_today, "Date", test_today),
        (365, "Date", date(1971, 1, 1)),
        (3600 * 24 * 365, "Datetime", datetime(1971, 1, 1, 0, 0)),
        (datetime(1970, 1, 1, 4, 0, tzinfo=tz4h), "Timestamp", datetime(1970, 1, 1, 0, 0)),
        (test_td, "Interval", test_td),
        (test_now, "Timestamp", test_now),
        (
            1511789040123456,
            "Timestamp",
            datetime.fromisoformat("2017-11-27 13:24:00.123456"),
        ),
        ('{"foo": "bar"}', "Json", {"foo": "bar"}),
        ('{"foo": "bar"}', "JsonDocument", {"foo": "bar"}),
    ],
)
@pytest.mark.asyncio
async def test_types_native(driver, database, value, ydb_type, result_value):
    settings = (
        ydb.TableClientSettings()
        .with_native_date_in_result_sets(True)
        .with_native_datetime_in_result_sets(True)
        .with_native_timestamp_in_result_sets(True)
        .with_native_interval_in_result_sets(True)
        .with_native_json_in_result_sets(True)
    )

    client = ydb.TableClient(driver, settings)
    session = await client.session().create()

    prepared = await session.prepare(f"DECLARE $param as {ydb_type}; SELECT $param as value")

    result = await session.transaction().execute(prepared, {"$param": value}, commit_tx=True)
    assert result[0].rows[0].value == result_value
